@@ -13,18 +13,18 @@ static char * Xinvest_m_pm[] = {
 ".....        ....XXX.....  .....",
 "...XXX        ...XXX....XXX.....",
 "...XXX        ...XXX....XXX.....",
-"...XXX.        ..XXXX.. XXX.....",
-"...XXX..        .XXXX.  XXX.....",
-"...XXX...        XXXX  .XXX.....",
+"...XXX.        ..XXXX..XXXX.....",
+"...XXX..        .XXXX. XXXX.....",
+"...XXX...        XXXX  XXXX.....",
 "...XXX...        XXX  ..XXX.....",
 "...XXX....XXX    XXX  ..XXX.....",
-"...XXXX...XXX    XXX ...XXX.....",
-"...XXXX...XXX    XXX....XXX.....",
-"...XXXX...XXX   .XXX....XXXX....",
-"...XXX....XXX  . XXX ...XXXX....",
-"...XXX....XXX .  XXX  ..XXXX....",
-"...XXX....XXX..  XXX   .XXX.....",
-"...XXX....XXX..  XXX   .XXX.....",
+"...XXXX...XXX   XXXX ...XXX.....",
+"...XXXX...XXX   XXXX....XXX.....",
+"...XXXX..XXXX   XXXX....XXXX....",
+"...XXX...XXXX  . XXX ...XXXX....",
+"..XXXX...XXXX .  XXX  ..XXXX....",
+"..XXXX....XXX..  XXX   .XXX.....",
+"..XXXX....XXX..  XXX   .XXX.....",
 "...XXX....XXX... XXX    XXX.....",
 "...XXX... XXX....XXX    XXX.....",
 "...XXX..  XXXX....      XXX.....",
