@@ -1,6 +1,6 @@
 /*
-  Xinvest Copyright 1995-97 Mark Buser, 
-  All Rights Reserved.
+  Xinvest Copyright (c)1995-98, 2000 
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -20,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.19 $ $Date: 1997/09/20 17:01:52 $
+  $Revision: 2.32 $ $Date: 2000/02/04 22:47:26 $
 */
 
 #include <stdlib.h>
@@ -56,6 +56,10 @@ typedef struct accnt {
   NAV  *calc_nav;         /* current date, price */
   char *title;            /* title */
   char *ticker;           /* ticker symbol */
+  char *eticker;          /* ticker modifier */
+  char *cticker;          /* currency ticker symbol */
+  char *ecticker;         /* ticker modifier */
+  NAV  *curr_nav;         /* currency date, price */
   int  transno;           /* # transactions */
   TRANS *trans;           /* the transactions */
   PLOT_VAR  *plot;        /* the plot variables selected and attributes */
@@ -70,6 +74,7 @@ static void accountDirty();
 static void makeAccountMenu();
 static void setAccountMenuItem ( int );
 
+extern Widget Toplevel;   /* Dialog parent  */
 extern Widget Transtext;  /* Transaction text widget */
 
 
@@ -199,6 +204,15 @@ int newAccount ( char *filename, char *transtext, int writable )
   }
   account[accountno].title = NULL;
   account[accountno].ticker = NULL;
+  account[accountno].eticker = NULL;
+  account[accountno].cticker = NULL;
+  account[accountno].ecticker = NULL;
+  /* curr_nav set in processAccount */
+  account[accountno].curr_nav = (NAV *)XtCalloc (1, sizeof(NAV));
+  if (account[accountno].curr_nav == NULL) {
+    write_status ("Out of memory: could not create new account.", ERR);
+    return(0);
+  }
   account[accountno].transno = 0;
   account[accountno].trans = NULL;
   account[accountno].plot = makeGraphVar();
@@ -214,24 +228,21 @@ void closeAccount ( int index )
     /* Has account been modified */
     if (account[index].flags & ACCOUNT_DIRTY ) {
       char prompt[] = "Account has been changed, close anyway?";
-      if ( AskUser ( account[index].textWidget, prompt, "OK", 
+      if ( AskUser ( Toplevel, prompt, "OK", 
                      "Cancel", YES) == NO )
         return;
     }
 
-    /* Is it in the porfolio? */
+    /* Is it in the portfolio? */
     if ( account[index].filename && 
          account[index].flags & ACCOUNT_IN_PORTFOLIO ) {
        char prompt[] = "Account is in the portfolio, close anyway?";
-       if ( AskUser ( account[index].textWidget, prompt, "OK", 
-                      "Cancel", YES) == NO )
+       if ( AskUser ( Toplevel, prompt, "OK", "Cancel", YES) == NO )
          return;
        else {
          portAccount( index, PORT_DELETE);
-         /* Changed portfolio, redraw pie.  It may not be on, but we don't 
-         ** know that. */
-         portUpdateDisplay();  
-         portSense();
+         portUpdateDisplay();
+	 /* displayAccount takes care of redraw */
        }  
     }
 
@@ -246,6 +257,14 @@ void closeAccount ( int index )
       XtFree ( account[index].title );
     if ( account[index].ticker )
       XtFree ( account[index].ticker );
+    if ( account[index].eticker )
+      XtFree ( account[index].eticker );
+    if ( account[index].cticker )
+      XtFree ( account[index].cticker );
+    if ( account[index].ecticker )
+      XtFree ( account[index].ecticker );
+    if ( account[index].curr_nav )
+      XtFree ( (char *)account[index].curr_nav );
     if (account[index].trans)
       XtFree ( (char *)account[index].trans );
     if (account[index].plot)
@@ -260,6 +279,10 @@ void closeAccount ( int index )
       account[index].calc_nav   = account[index+1].calc_nav;
       account[index].title      = account[index+1].title;
       account[index].ticker     = account[index+1].ticker;
+      account[index].eticker    = account[index+1].eticker;
+      account[index].cticker    = account[index+1].cticker;
+      account[index].ecticker   = account[index+1].ecticker;
+      account[index].curr_nav   = account[index+1].curr_nav;
       account[index].transno    = account[index+1].transno;
       account[index].trans      = account[index+1].trans;
       account[index].plot       = account[index+1].plot;
@@ -275,7 +298,7 @@ void closeAccount ( int index )
       char prompt[] = "Memory error removing account. Account\n"
                       "pointer is corrupt. Exiting Xinvest without\n"
                       "saving changes.\n";
-      AskUser ( Transtext, prompt, "OK", "Cancel", YES );
+      AskUser ( Toplevel, prompt, "OK", "Cancel", YES );
       exit(-1);
     }
 
@@ -288,47 +311,68 @@ void closeAccount ( int index )
 void processAccount ( int num ) 
 {
   char *transtext;
-  char *cp;
+  char *front, *back;
 
   char *error = NULL;
-  char err_msg[132];
+  int reAdd = False;
 
   if (num == 0)
     return;
 
-  /* Copy transactions for destructive process */
-  transtext = strdup( account[num].transText );
+  /* Is it in the porfolio? Ask user if we should refresh */
+  if (account[num].flags & ACCOUNT_IN_PORTFOLIO ) {
+    char prompt[] = "Account is in the portfolio, update?";
+    if ( AskUser ( Toplevel, prompt, "OK", "Cancel", YES) == NO )
+      return;
+    else {
+      portAccount( num, PORT_DELETE);
+      portUpdateDisplay();
+      /* Need to re-add after update */
+      reAdd = True;
+    }
+  }
+
+  if (account[num].transText) {
+    int len;
+
+    /* Copy transactions for destructive process */
+    transtext = strdup (account[num].transText);
+    len = strlen (transtext);
   
-  /* Will last line always be processed if no trailing \n? */
+    /* 
+    ** Fill in transaction structures 
+    */
+    front = transtext;
+    if ((back = strchr(transtext, '\n')))
+      *back = '\0';                 /* write NULL to end of 1st line */
+    /* Always process once, even if its NULL, to clear out trans struct */
+    error = rd_trans (front, T_NEW);
 
-  /* 
-  ** Fill in transaction structures 
-  */
-
-  /* cp points to 2nd line (if any) */
-  cp = strtok ( transtext, "\n" );   /* write null to end of 1st line */
-
-  /* Always process once, even if its NULL, to clear out trans struct */
-  error = rd_trans ( transtext, T_NEW );
-
-  /* If 2nd line */
-  if (cp == transtext)
-    cp = strtok ( NULL, "\n" );
-
-  /* 3rd+ line, look for newlines to feed to rd_trans */
-  while ( cp && !error) {
-    error = rd_trans ( cp, T_SAME );
-    cp = strtok ( NULL, "\n" );
-  }
+    /* 2nd+ line, look for newlines to feed to rd_trans */
+    if (back && (front = back+1) < (transtext+len)) {
+      back = strchr (front, '\n');
+    } else {
+      back = NULL;
+    }
+    while (back && !error) {
+      *back = '\0';                   /* write NULL to end of line */
+      error = rd_trans (front, T_SAME);
+      if ((front = back+1) < (transtext+len)) {
+        back = strchr (front, '\n');
+      } else {
+        back = NULL;
+      }
+    }
  
-  if (error) {
-    char *name = createAccountName (num);
-    sprintf( err_msg, "%s:\n%s", name, error );
-    write_status ( err_msg, ERR);
-    XtFree (name);
-  }
+    if (error) {
+      char *name = createAccountName (num);
+      sprintf (errmsg, "%s:\n%s", name, error);
+      write_status (errmsg, ERR);
+      XtFree (name);
+    }
 
-  XtFree ( transtext );
+    XtFree (transtext);
+  }
 
   /* Save the transactions for later */
   if (account[num].trans)
@@ -344,7 +388,16 @@ void processAccount ( int num )
   /* Set ticker info */
   if (account[num].ticker)
     XtFree (account[num].ticker);
-  account[num].ticker = GetTransTicker();
+  account[num].ticker = XtNewString(GetTransTicker());
+  if (account[num].eticker)
+    XtFree (account[num].eticker);
+  account[num].eticker = XtNewString(GetTransETicker());
+  if (account[num].cticker)
+    XtFree (account[num].cticker);
+  account[num].cticker = XtNewString(GetTransCurrTicker());
+  if (account[num].ecticker)
+    XtFree (account[num].ecticker);
+  account[num].ecticker = XtNewString(GetTransCurrETicker());
 
   /* We're up to date */
   account[num].flags &= ~ACCOUNT_UPDATE;
@@ -353,13 +406,15 @@ void processAccount ( int num )
   if ( account[num].transno ) {
 
     /* Set NAV info from last transaction */
-    sscanf( GetTransDate( account[num].trans, account[num].transno ), 
-            "%d/%d/%d", 
+    char *date = GetTransDate( account[num].trans, account[num].transno);
+    sscanf (date, "%d/%d/%d", 
             &account[num].calc_nav->month, &account[num].calc_nav->date, 
-            &account[num].calc_nav->year );
+            &account[num].calc_nav->year);
+    account[num].calc_nav->value = GetTransNav (account[num].trans,
+                                                account[num].transno);
+    account[num].curr_nav->value = GetTransCurrency (account[num].trans,
+                                                     account[num].transno);
 
-    account[num].calc_nav->value = GetTransNav ( account[num].trans,
-                                                 account[num].transno );
   } else {
     time_t t = time ( (time_t *)0 );
     struct tm *today = localtime (&t);
@@ -371,6 +426,16 @@ void processAccount ( int num )
       account[num].calc_nav->year += 1900;
 
     account[num].calc_nav->value = 0.0;
+    account[num].curr_nav->value = 1.0;
+  }
+
+  account[num].curr_nav->month = account[num].calc_nav->month;
+  account[num].curr_nav->date = account[num].calc_nav->date;
+  account[num].curr_nav->year = account[num].calc_nav->year;
+
+  if (reAdd) {
+    portAccount (num, PORT_ADD);
+    portUpdateDisplay();
   }
 
 }
@@ -385,7 +450,7 @@ void displayAccount (int num)
 
   int  new, enable;
   Widget menu;
-  int managedAccount = 0;        /* Last account in Transtext */
+  int managedAccount = 0;        /* Last account in transaction window */
 
   XmString title_str;
 
@@ -396,7 +461,7 @@ void displayAccount (int num)
   if ( num == 0 ) 
     new = 0;
 
-  /* _activeAccount is no more, show last transaction */
+  /* _activeAccount is no more, show last account */
   else if ( num < 0 ) {
     if ( (new = (_activeAccount -1)) < 1)
       new = accountno;
@@ -610,6 +675,10 @@ void getAccount (int index, int field, void *val )
            *(char **)val = account[index].ticker;
            break;
 
+      case ACCOUNT_ETICKER:
+           *(char **)val = account[index].eticker;
+           break;
+
       case ACCOUNT_NAV: 
            *(NAV **)val = account[index].calc_nav;
            break;
@@ -630,6 +699,18 @@ void getAccount (int index, int field, void *val )
            *(PLOT_VAR **)val = account[index].plot;
            break;
 
+      case ACCOUNT_CURRENCY: 
+           *(NAV **)val = account[index].curr_nav;
+           break;
+
+      case ACCOUNT_CTICKER:
+           *(char **)val = account[index].cticker;
+           break;
+
+      case ACCOUNT_ECTICKER:
+           *(char **)val = account[index].ecticker;
+           break;
+
       default:
           write_status ("Can't return value, no such field.", WARN);
           *(char **)val = NULL;
@@ -690,6 +771,11 @@ static void selectCB (Widget w,
   }
 }
 
+#define PREV_ACCT 0
+#define NEXT_ACCT 1
+#define UPDT_ACCT 2
+#define MORE_ACCT 3
+
 /* ARGSUSED */
 void accountCB (Widget w, int item_no, XmAnyCallbackStruct *call_data)
 {
@@ -703,8 +789,8 @@ void accountCB (Widget w, int item_no, XmAnyCallbackStruct *call_data)
 
   switch (item_no) {
 
-    case 0: /* Prev account */
-    case 1: /* Next account */
+    case PREV_ACCT: /* Prev account */
+    case NEXT_ACCT: /* Next account */
             if (accountno > 1) {
               int offset = (item_no)?1:-1;
               int next;
@@ -725,7 +811,7 @@ void accountCB (Widget w, int item_no, XmAnyCallbackStruct *call_data)
             }
             break;
 
-    case 2: /* Update account */
+    case UPDT_ACCT: /* Update account */
             if ( account[_activeAccount].transText )
               XtFree ( account[_activeAccount].transText );
             account[_activeAccount].transText = 
@@ -736,12 +822,12 @@ void accountCB (Widget w, int item_no, XmAnyCallbackStruct *call_data)
 
             break;
 
-    case 3: /* More accounts */
+    case MORE_ACCT: /* More accounts */
 
             if (dialog == NULL) {
               num = 0;
               XtSetArg ( args[num], XmNautoUnmanage, False); num++;
-              dialog = XmCreateSelectionDialog( Transtext, "Accountsel",
+              dialog = XmCreateSelectionDialog( Toplevel, "Accountsel",
                                                 args, num);
 
               /* I don't need these */
@@ -895,12 +981,12 @@ static void makeAccountMenu()
                           xmPushButtonGadgetClass, Accountmenu,
                           NULL );
     XtAddCallback ( newbutton, XmNactivateCallback,
-                  (XtCallbackProc) accountCB, (XtPointer) 2 );
+                  (XtCallbackProc) accountCB, (XtPointer) 3 );
   }
 
   /* If dialog is up, update its contents */
   if (dialog)
-    accountCB ( NULL, 2, NULL);
+    accountCB ( NULL, MORE_ACCT, NULL);
 }
 
 /* 
@@ -911,19 +997,23 @@ char *createAccountName( int which )
 {
   char *name;
 
-  if (which == ALL_ACCOUNTS) {
-    name = XtNewString ("Portfolio");
-  } else {
-    char *title;
-    getAccount ( which, ACCOUNT_TITLE, &title );
-    if (title) {
-      name = XtNewString (title);
-    } else {
-      if ( (name = XtCalloc (1, 12*sizeof(char))) )
-        sprintf ( name, "Account %3d", which);
-    }
+  if (which == ALL_ACCOUNTS)
+    return (XtNewString ("Portfolio"));
+
+  getAccount (which, ACCOUNT_TITLE, &name);
+  if (name)
+    return (XtNewString (name));
+
+  getAccount (which, ACCOUNT_FILENAME, &name);
+  if (name)
+    return (XtNewString(name));
+
+  if ((name = XtCalloc (1, 12*sizeof(char)))) {
+    sprintf (name, "Account %3d", which);
+    return (name);
   }
-  return (name);
+
+  return ("ERROR: could not generate account name.");
 }
 
 void saveAccount ( FILE *savefile, int index)
@@ -941,6 +1031,53 @@ void saveAccount ( FILE *savefile, int index)
               account[index].calc_nav->year, account[index].calc_nav->value );
 }
 
+double accountApplyModifier (char *modifier, double nav) {
+  char *next, *end, *end_opnd;
+  char err_msg[60];
+  double result = nav, opnd;
+
+  if (modifier == NULL)
+    return (nav);
+
+  next = modifier;
+  end = modifier + strlen(modifier);
+  strcpy (err_msg, "");
+
+  while (next < end) {
+    if (strncasecmp (next, "/X", 2) == 0) {        /* Invert */
+      if (result != 0.0)
+        result = 1.0/result;
+      else
+        strcpy (err_msg, "Ticker modifier /X - divide by 0 exception.");
+      next += 2;
+    } else if (strncasecmp (next, "/", 1) == 0) {  /* Divide */
+      opnd = strtod (++next, &end_opnd); 
+      if (end_opnd && end_opnd != next) {  /* Got an operand */
+        next = end_opnd;
+        if (opnd != 0.0)
+          result /= opnd; 
+        else
+          strcpy (err_msg, "Ticker modifier / - divide by 0 operand.");
+      } else                               /* No or unknown one */
+        sprintf (err_msg, "Ticker modifier - Unknown operand '%s'.\n", next);
+    } else if (strncasecmp(next, "*", 1) == 0) {   /* Multiply */
+      opnd = strtod (++next, &end_opnd); 
+      if (end_opnd && end_opnd != next) {
+        next = end_opnd;
+        result *= opnd; 
+      } else
+        sprintf (err_msg, "Ticker modifier - Unknown operand '%s'.\n", next);
+    } else {
+      sprintf (err_msg, "Ticker modifier - Unknown operator '%s'.\n", next);
+    }
+    if (strlen(err_msg)) {
+      write_status (err_msg, ERR);
+      return (nav);
+    }
+  }
+  return (result);
+}
+
 int accountMatchTicker (char *ticker, int month, int day, int year, 
                         double nav)
 {
@@ -948,15 +1085,27 @@ int accountMatchTicker (char *ticker, int month, int day, int year,
   char *acct_ticker;
 
   for (accountno=1; accountno <= numAccounts(); accountno++) {
+    /* Account Price */
     getAccount ( accountno, ACCOUNT_TICKER, &acct_ticker);
     if (acct_ticker && (strcasecmp (ticker, acct_ticker) == 0) ) {
       found = 1;
       account[accountno].calc_nav->month = month;
       account[accountno].calc_nav->date = day;
       account[accountno].calc_nav->year = year;
+      getAccount (accountno, ACCOUNT_ETICKER, &acct_ticker);
+      nav = accountApplyModifier (acct_ticker, nav);
       account[accountno].calc_nav->value = nav;
-      if (accountno == _activeAccount)
-        displayReport(accountno);    /* inform report of account change */
+    }
+    /* Account Exchange Rate */
+    getAccount ( accountno, ACCOUNT_CTICKER, &acct_ticker);
+    if (acct_ticker && (strcasecmp (ticker, acct_ticker) == 0) ) {
+      found = 1;
+      account[accountno].curr_nav->month = month;
+      account[accountno].curr_nav->date = day;
+      account[accountno].curr_nav->year = year;
+      getAccount (accountno, ACCOUNT_ECTICKER, &acct_ticker);
+      nav = accountApplyModifier (acct_ticker, nav);
+      account[accountno].curr_nav->value = nav;
     }
   }
   return ((found)?accountno:0);
