@@ -1,5 +1,5 @@
 /*
-  Xinvest Copyright 1995-97 Mark Buser,
+  Xinvest/Xquote Copyright (c)1995-97 Mark Buser,
   All Rights Reserved.
 
   Permission is hereby granted to copy
@@ -10,7 +10,7 @@
   
   All redistributions must be in their
   entirety as originally distributed.
-  Feel free to modify Xinvest, but
+  Feel free to modify Xinvest/Xquote, but
   modified versions may not be distributed
   without prior consent of the author.
   
@@ -20,9 +20,8 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.1 $ $Date: 1997/07/20 18:40:44 $
+  $Revision: 2.3 $ $Date: 2000/01/08 13:42:08 $
 */
-
 #ifndef COLOR_H
 #define COLOR_H
 
@@ -36,18 +35,19 @@ enum {
        USER5,
        USER6,
        USER7,
-       RED,    /* allocate by name, because we always need */
+       RED,    /* defined in app defaults, but we always need */
        GREEN, 
        GREY,
        WHITE,
        BLACK
 } Colors;
 #define COLOR_NUM (USER7+1)
+#define COLOR_DEF (BLACK+1)
 
 Colormap InitColor( Widget, Colormap, Pixel * );
 Colormap NewColormap( Display *, Colormap );
 Colormap GetColormap();
-Pixel    GetColor( int );     /* Get named color from color table */
+Pixel    GetColor( int );      /* Get named color from color table */
 int isColorVisual (Display *); /* Return true if visual implies color */
 int isDarkPixel (Display *, Pixel);
 #endif
