@@ -1,6 +1,6 @@
 /*
-  Xinvest Copyright 1997 by Mark Buser,
-  All Rights Reserved.
+  Xinvest Copyright (c)1997, 2000 
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -20,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 1.1 $ $Date: 1997/07/20 18:41:39 $
+  $Revision: 1.3 $ $Date: 2000/01/08 13:42:37 $
 */
 #ifndef COLORP_H
 #define COLORP_H
@@ -28,7 +28,7 @@
 /* This must match order of enum Colors in color.h */
 static char *colors[] = { 
 NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,   /* user app colors */
-"Red", "Forest Green", "Grey60", "White", "Black" /* local named colors */
+NULL, NULL, NULL, NULL, NULL                      /* local named colors */
 };
 
 #endif
