@@ -1,5 +1,6 @@
 /*
-  Xinvest is copyright 1995,1996 by Mark Buser.
+  Xinvest is copyright 1995-98 Mark Buser,
+  All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -19,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.12 $ $Date: 1997/08/16 20:52:42 $
+  $Revision: 2.19 $ $Date: 2000/01/31 22:13:03 $
 */
 
 #include <limits.h>
@@ -27,6 +28,7 @@
 #include <stdlib.h>
 #include <dirent.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -41,17 +43,19 @@
 #include "account.h"
 #include "askuser.h"
 #include "drawing.h"
-#include "trans.h"
+#include "pref.h"
+#include "session.h"
 #include "status.h"
+#include "trans.h"
 #include "util.h"
 #include "xutil.h"
 
 extern Widget Filecwdlabel;
 extern Widget Listfile;
+extern Widget Toplevel;       /* dialog parent */
 extern Widget Transtext;
 
 static char prompt[BUFSIZ];
-static char err_msg[BUFSIZ];
 
 /* forward declarations */
 static void newfile ( );
@@ -175,8 +179,8 @@ int loadfile ( char *choice )
   XmString dir_str;
 
   if (stat ( choice, &statb )  != 0 ) {
-    sprintf ( err_msg, "Couldn't query file:\n\"%s\"", choice);
-    write_status (err_msg, ERR);
+    sprintf ( errmsg, "Couldn't query file:\n\"%s\"", choice);
+    write_status (errmsg, ERR);
     return( (int)NULL );
   }
 
@@ -184,14 +188,14 @@ int loadfile ( char *choice )
     /* open directory and list choices */
     dirp = opendir( choice );
     if ( dirp == NULL ) {
-      sprintf ( err_msg, "Couldn't open directory:\n\"%s\"", choice);
-      write_status (err_msg, ERR);
+      sprintf ( errmsg, "Couldn't open directory:\n\"%s\"", choice);
+      write_status (errmsg, ERR);
       closedir ( dirp );
       return( (int)NULL );
     }
     if ( (chdir ( choice )) == -1) {
-      sprintf ( err_msg, "Couldn't change to directory:\n\"%s\"", choice);
-      write_status (err_msg, ERR);
+      sprintf ( errmsg, "Couldn't change to directory:\n\"%s\"", choice);
+      write_status (errmsg, ERR);
       closedir ( dirp );
       return( (int)NULL );
     }
@@ -218,8 +222,8 @@ int loadfile ( char *choice )
 
        /* Get status, just skip if we can't stat */
        if (stat ( dp->d_name, &statb )  != 0 ) {
-         sprintf ( err_msg, "Couldn't query file:\n\"%s\"", dp->d_name);
-         write_status ( err_msg, WARN );
+         sprintf ( errmsg, "Couldn't query file:\n\"%s\"", dp->d_name);
+         write_status ( errmsg, WARN );
          continue;          /* skip bad files, dangling link? */
        }
        strcpy( buffer, dp->d_name);
@@ -298,9 +302,9 @@ int loadfile ( char *choice )
         strcat ( path, "/" );
         strcat ( path, choice );
       } else {
-        sprintf (err_msg, "Path longer than maximum (%d),\nfile not added.", 
+        sprintf (errmsg, "Path longer than maximum (%d),\nfile not added.", 
 	         num);
-        write_status ( err_msg, ERR);
+        write_status ( errmsg, ERR);
         return ( (int)NULL );
       }
     } else 
@@ -308,36 +312,36 @@ int loadfile ( char *choice )
 
     /* Is this account already open */
     if ( (num = accountIsOpen ( path )) ) {
-      sprintf ( err_msg, "File \"%s\" is already open, reload?", choice);
-      if ( AskUser (GetTopShell(Transtext), err_msg, "OK", "Cancel", YES) == NO)
+      sprintf ( errmsg, "File \"%s\" is already open, reload?", choice);
+      if ( AskUser (Toplevel, errmsg, "OK", "Cancel", YES) == NO)
         return ( num );
     }
  
     /* Is the file RO? */
     if ( !(statb.st_mode & S_IWUSR) ) {
-      sprintf ( err_msg, "File \"%s\" is read only.", choice);
-      write_status ( err_msg, INFO );
+      sprintf ( errmsg, "File \"%s\" is read only.", choice);
+      write_status ( errmsg, INFO );
     }
 
     /* Open the file */
     if ( ( file = fopen ( choice, "r") ) == NULL ) {
-      sprintf( err_msg, "Couldn't open file:\n\"%s\".", choice );
-      write_status ( err_msg, ERR );
+      sprintf( errmsg, "Couldn't open file:\n\"%s\".", choice );
+      write_status ( errmsg, ERR );
       return ( (int)NULL ); 
     }
 
     /*  Allocate space and read transactions */
     if (!(text = XtMalloc ( (unsigned) (statb.st_size + 1) ))) {
-      sprintf( err_msg, "Can't allocate memory to hold file:\n\"%s\".", 
+      sprintf( errmsg, "Can't allocate memory to hold file:\n\"%s\".", 
                choice );
-      write_status ( err_msg, ERR );
+      write_status ( errmsg, ERR );
       fclose ( file );
       return( (int)NULL );
     }
 
     if (statb.st_size && !fread ( text, sizeof (char), statb.st_size, file) ) {
-      sprintf( err_msg, "Did not read entire file:\n\"%s\".", choice);
-      write_status ( err_msg, WARN );
+      sprintf( errmsg, "Did not read entire file:\n\"%s\".", choice);
+      write_status ( errmsg, WARN );
     }
     text[statb.st_size] = 0;  /* NULL terminate */ 
 
@@ -360,8 +364,8 @@ static void writefile ( char *dir )
 
 
   if ( ( fp = fopen ( dir, "w") ) == NULL ) {
-    sprintf( err_msg, "Couldn't open file:\n\"%s\".", dir );
-    write_status ( err_msg, ERR );
+    sprintf( errmsg, "Couldn't open file:\n\"%s\".", dir );
+    write_status ( errmsg, ERR );
     return;
   }
 
@@ -381,8 +385,6 @@ static void writefile ( char *dir )
 ** Callback routines 
 */
 
-#define BAKEXT ".bak"
-
 /* Callback for file menu and quit button */
 void fileCB (Widget w, int client_data, XmAnyCallbackStruct *call_data )
 {
@@ -392,12 +394,13 @@ void fileCB (Widget w, int client_data, XmAnyCallbackStruct *call_data )
   int item_no = (int) client_data;
 
   char *filename;
+  char *fileext;
   char *savefilename;
   char *insert;
 
   /* Make a file selection dialog if we don't have one */
   if (!dialog) {
-    dialog = XmCreateFileSelectionDialog (GetTopShell(Transtext), "Filesel", 
+    dialog = XmCreateFileSelectionDialog (Toplevel, "Filesel", 
                                           NULL, 0);
     XtSetSensitive (XmFileSelectionBoxGetChild (dialog, XmDIALOG_HELP_BUTTON),
                     False);
@@ -450,26 +453,29 @@ void fileCB (Widget w, int client_data, XmAnyCallbackStruct *call_data )
 
     strcpy ( prompt, "Ok to overwrite file ");
     strcat ( prompt, filename );
-    if ( AskUser (GetTopShell(Transtext), prompt, "OK", "Cancel", YES) == NO )
+    if (AskUser (Toplevel, prompt, "OK", "Cancel", YES) == NO)
       return;
 
-    /* Move orig file to .bak */
-    savefilename = (char *) XtCalloc (strlen(filename) + strlen(BAKEXT) +1, 
+    if (prefGetBack(&fileext)) {
+      /* Backup original file */
+      savefilename = (char *) XtCalloc (strlen(filename) + strlen(fileext) +1, 
                                       sizeof(char));
-    strcpy ( savefilename, filename );
-    if ( (insert = strrchr ( savefilename, '.')) != NULL ) 
-      strcat ( insert, BAKEXT);
-    else
-      strcat ( savefilename, BAKEXT);
-    if (rename ( filename, savefilename )) {
-      sprintf ( err_msg, 
-                "Changes not saved, couldn't create backup file:\n\"%s\"", 
-                savefilename);
-      write_status ( err_msg, ERR);
-      XtFree ( savefilename );
-      return;
+      strcpy (savefilename, filename);
+      /* If there's an extension replace it, otherwise append one */
+      if ((insert = strrchr (savefilename, '.')) != NULL) 
+        strcpy (insert+1, fileext);      
+      else 
+        sprintf (savefilename, "%s.%s", filename, fileext);
+      if (rename (filename, savefilename)) {
+        sprintf (errmsg, 
+                 "Changes not saved, couldn't create backup file:\n\"%s\"", 
+                 savefilename);
+        write_status (errmsg, ERR);
+        XtFree (savefilename);
+        return;
+      }
+      XtFree (savefilename);
     }
-    XtFree ( savefilename );
 
     writefile ( filename ); 
 
@@ -485,10 +491,16 @@ void fileCB (Widget w, int client_data, XmAnyCallbackStruct *call_data )
     XtPopup( XtParent(dialog), XtGrabNone);
   }
 
-  else if (item_no == 5) {     /* the quit button */
+  else if (item_no == 5) {     /* Manual save state */
+    char *filename = sessSaveFile (True);
+    saveState (filename);
+    XtFree (filename);
+  }
+
+  else if (item_no == 6) {     /* the quit button */
     if ( accountsStatus(ACCOUNT_DIRTY) ) {
       strcpy ( prompt, "At least one account has been changed, quit anyway?");
-      if ( AskUser (GetTopShell(Transtext), prompt, "OK", "Cancel", YES) == NO )
+      if ( AskUser (Toplevel, prompt, "OK", "Cancel", YES) == NO )
         return;
     }
 
@@ -508,6 +520,7 @@ static void saveAsfileCB ( Widget w, XtPointer client_data,
                            XtPointer call_data )
 {
   char *filename;
+  char *fileext;
   char *savefilename;
   char *insert;
 
@@ -543,27 +556,28 @@ static void saveAsfileCB ( Widget w, XtPointer client_data,
       strcpy ( prompt, "Ok to overwrite file ");
       strcat ( prompt, filename );
       strcat ( prompt, "?");
-      if ( AskUser (GetTopShell(Transtext), prompt, "OK", "Cancel", YES) == NO )
+      if ( AskUser (Toplevel, prompt, "OK", "Cancel", YES) == NO )
         return;
 
-      /* Move orig file to .bak */
-      savefilename = (char *) XtCalloc (strlen(filename) + strlen(BAKEXT) +1, 
-                                        sizeof (char ) );
-      strcpy ( savefilename, filename );
-      if ( (insert = strrchr ( savefilename, '.')) != NULL ) 
-        strcat ( insert, BAKEXT);
-      else
-        strcat ( savefilename, BAKEXT);
-      if (rename ( filename, savefilename )) {
-        sprintf ( prompt, 
-                  "Changes not saved, couldn't create backup file:\n\"%s\"", 
-                  savefilename);
-        write_status ( err_msg, ERR);
+      if (prefGetBack(&fileext)) {
+        /* Backup original file */
+        savefilename = (char *) XtCalloc (strlen(filename) + strlen(fileext)+1, 
+                                        sizeof (char ));
+        strcpy (savefilename, filename );
+        if ((insert = strrchr ( savefilename, '.')) != NULL) 
+          strcat (insert, fileext);
+        else
+          strcat (savefilename, fileext);
+        if (rename (filename, savefilename)) {
+          sprintf (prompt, 
+                   "Changes not saved, couldn't create backup file:\n\"%s\"", 
+                   savefilename);
+          write_status (errmsg, ERR);
+          XtFree ( savefilename );
+          return;
+        }
         XtFree ( savefilename );
-        return;
       }
-      XtFree ( savefilename );
-
     }
   }
 
@@ -583,7 +597,6 @@ static void saveAsfileCB ( Widget w, XtPointer client_data,
   XtUnmanageChild ( w ); 
 }
 
-#undef BAKEXT
 
 static void newfile ( )
 {
@@ -599,7 +612,6 @@ static void newfile ( )
   /* A freeable text string */
   char *text = strdup (newtext);
 
-  
   /* No remembered filename, just transaction text, assume writable */
   nextaccount = newAccount ( NULL, text, True ); 
   if (nextaccount) {
