@@ -1,5 +1,6 @@
 /*
-  Xinvest is copyright 1995 by Mark Buser.
+  Xinvest Copyright (c)1995-98 Mark Buser,
+  All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -19,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.9 $ $Date: 1997/01/13 22:46:19 $
+  $Revision: 2.11 $ $Date: 1998/05/02 15:56:52 $
 */
 
 #include <stdlib.h>
@@ -33,6 +34,7 @@
 #include "drawing.h"
 #include "pixmap.h"
 #include "status.h"
+#include "util.h"
 #include "xutil.h"
 
 #define PV   0
@@ -91,19 +93,11 @@ static void update_result_text(double result, int func) {
     if ( num_ok[i] == 0 )
       strcpy( var[i], vars_str[func][i] );
     else {
-#ifdef STRFMON
       if ( strcmp(vars_str[func][i], "RATE") == 0 ||
            strcmp(vars_str[func][i], "YEARS") == 0 )
-         strfmon( var[i], 15, "%!.2n", num_ok[i] );
+         sprintf( var[i], "%.15s", utilCurrOut(num_ok[i], UTILNUM));
       else
-         strfmon( var[i], 15, "%.2n", num_ok[i] );
-#else
-      if ( strcmp(vars_str[func][i], "RATE") == 0 ||
-           strcmp(vars_str[func][i], "YEARS") == 0 )
-        sprintf( var[i], "%.2f", num_ok[i] );
-      else
-        sprintf( var[i], "$%.2f", num_ok[i] );
-#endif
+         sprintf( var[i], "%.15s", utilCurrOut(num_ok[i], UTILCURR));
     }
   }
 
@@ -111,12 +105,8 @@ static void update_result_text(double result, int func) {
   if ( result == 0)
     strcpy( var[3], vars_str[func][3] );
   else
-#ifdef STRFMON
     /* Equation 4 result is rate, leave off currency symbol. */
-    strfmon( var[3], 15, (func==4)?"%!.2n":"%.2n", result );
-#else
-    sprintf( var[3], (func==4)?"%.2f":"$%.2f", result );
-#endif
+    sprintf (var[i], "%.15s", utilCurrOut (result, (func==4)?UTILNUM:UTILCURR));
 
   sprintf ( result_str, format_str[ curr_func ], var[0], var[1], 
             compound_str[last_compound], var[2], var[3] );
