@@ -1,6 +1,6 @@
 /*
-  Xinvest is Copyright 1995-97 Mark Buser,
-  All Rights Reserved.
+  Xinvest Copyright (c)1995-99, 2000
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -20,9 +20,10 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.31 $ $Date: 1997/08/19 11:43:46 $
+  $Revision: 2.41 $ $Date: 2000/02/04 00:42:58 $
 */
 
+#include <float.h>
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -44,6 +45,7 @@
 #include "rate.h"
 #include "status.h"
 #include "trans.h"
+#include "util.h"
 #include "xutil.h"
 
 #include "pixmaps/cumstipple.xbm"
@@ -53,8 +55,7 @@
 static int multiAccount = 0;
 static int v_active = 0;
 
-/* Remember where all the buttons are. We rely on an implicit initialization
-   to zero.  */
+/* Remember where the buttons are. We rely on implicit NULL initialization. */
 static Widget Graphvbuttons[NUM_PLOTS];
 
 /* Remember what's selected in single account mode */
@@ -130,13 +131,13 @@ static void SetDrawAttrib ( Widget Drawing, GC gc, int attrib )
                       2, line_style[ STYLE ], CapNotLast, JoinBevel );
 
   /* If we're LineOnOffDash set the next dash pattern */
-  if ( STYLE == 1)
+  if (STYLE == 1)
      XSetDashes ( XtDisplay (Drawing), gc, 0, dash_dash, strlen(dash_dash) );
-  if ( STYLE == 2)
+  if (STYLE == 2)
      XSetDashes ( XtDisplay (Drawing), gc, 0, dash_dot, strlen(dash_dot) );
 
   /* Set the fill style - plot by bar */
-  XSetFillStyle (  XtDisplay (Drawing), gc, fill_style[ STYLE ]);
+  XSetFillStyle ( XtDisplay (Drawing), gc, fill_style[ STYLE ] );
 
   /* If we're stipple set the next stipple pattern */
   if ( STYLE == 1)
@@ -522,16 +523,16 @@ void graphSense( int graphing)
   grid = XtNameToWidget ( Optionmenu, "button_2" );
 
   if (graphing) {
-     XtSetSensitive ( zoom, True);
+     XtSetSensitive (zoom, True);
      if (by_trans) 
-       XtSetSensitive ( spnt, False);
+       XtSetSensitive (spnt, False);
      else
-       XtSetSensitive ( spnt, True);
-     XtSetSensitive ( grid, True);
+       XtSetSensitive (spnt, True);
+     XtSetSensitive (grid, True);
   } else {
-    XtSetSensitive ( zoom, False);
-    XtSetSensitive ( spnt, False);
-    XtSetSensitive ( grid, False);
+    XtSetSensitive (zoom, False);
+    XtSetSensitive (spnt, False);
+    XtSetSensitive (grid, False);
   }
 }
 
@@ -545,9 +546,6 @@ void graph_hselect ( Widget w, XtPointer client_data, XtPointer call_data)
 
   int save_t = by_trans;
 
-  Widget scaleLabel;
-  XmString label_str;
-
   PLOT_VAR *accountGraph;
   int i;
 
@@ -565,16 +563,6 @@ void graph_hselect ( Widget w, XtPointer client_data, XtPointer call_data)
 
     constCheckPoint ( False, (int)NULL );
 
-    /* Change the MAVG label */
-    XtVaGetValues ( XtParent(w), XmNuserData, &scaleLabel, NULL);
-    if (by_trans)
-      label_str = XmStringCreateLocalized ( "Trans" );
-    else
-      label_str = XmStringCreateLocalized ( "Weeks" );
-    if (scaleLabel)
-      XtVaSetValues ( scaleLabel, XmNlabelString, label_str, NULL);
-    XmStringFree ( label_str );
-
     /* Get the attributes for this set of legends */
     accountGraph = graph_attrib ( activeAccount() );
 
@@ -625,7 +613,6 @@ void const_change ( Widget w, XtPointer client_data, XtPointer call_data)
 {
   
   char  *val, *check;
-  char  errmsg[80];
 
   val = XmTextGetString ( w );
   strtod ( val, &check);
@@ -853,86 +840,43 @@ static struct trans_value *calc_trans_values( int account, int transno,
 {
  PLOT_VAR *graphVar;
  void   *transactions;
+ int    numTrans;
  long   trans_date;
- int    trans_type;
- int    trans_reinvest;
- int    trans_major, trans_minor;
- double trans_shares;
- double trans_nav;
- double trans_load;
-
- NAV *navp;
- float nav_value;
-  
  static struct trans_value trans;
 
  graphVar = graph_attrib ( account );
  getAccount ( account, ACCOUNT_TRANS, &transactions );
+ getAccount ( account, ACCOUNT_NUM_TRANS, &numTrans );
 
  trans_date = GetTransLDate(transactions, transno);
- trans_type = GetTransType(transactions, transno);
- trans_shares = GetTransShares(transactions, transno);
- trans_nav = GetTransNav(transactions, transno);
- trans_load = GetTransLoad(transactions, transno);
- trans_reinvest = GetTransFlag(transactions, transno, TRANS_REINVEST);
- trans_major = GetTransSplit(transactions, transno, TRANS_MAJOR);
- trans_minor = GetTransSplit(transactions, transno, TRANS_MINOR);
 
- getAccount ( account, ACCOUNT_NAV, &navp );
- getNav ( navp, NAV_VALUE, &nav_value );
-
-
- /* Price */
- trans.value[PRICE-1] = trans_nav;
-
- /* Shares, if not reinvesting dividends don't count */
- if ( trans_type != T_DIST || trans_reinvest )
-   trans.value[SHARE-1] = trans_shares;
- else
-   trans.value[SHARE-1] = 0.0;
- /* Possible load on sale, we now have less shares */
- if ( trans_type == T_SELL )
-   trans.value[SHARE-1] -= (trans_load / trans_nav);
-
- /* Cost */
- if ( trans_type & (T_BUY | T_SELL) ) 
-   trans.value[COST-1] = trans_nav * trans_shares + trans_load;
- else if ( trans_type == T_DIST && !trans_reinvest )
-   trans.value[COST-1] = trans_nav * -trans_shares + trans_load;
- else
-   trans.value[COST-1] = 0.0;
-
- /* Value */
- trans.value[VALUE-1] = nav_value * trans.value[SHARE-1];
-
- /* Distribution */
- if ( trans_type == T_DIST )
-   trans.value[DISTRIB-1] = trans_nav * trans_shares;
- else
-   trans.value[DISTRIB-1] = 0.0;
-
- /* Initialize all cumulative sums */
- if (transno == 1) {
-   trans.value[SHARE_CUM-1] = 0.0;
-   trans.value[COST_CUM-1] = 0.0;
-   trans.value[VALUE_CUM-1] = 0.0;
-   trans.value[DISTRIB_CUM-1] = 0.0;
+ if (trans_date == GetTransLDate (transactions, numTrans)) {
+   trans.value[PRICE-1] = rate_price (account, CURRENT_DATE);
+   trans.value[VALUE-1] = rate_value (account, trans_date, CURRENT_DATE);
+   trans.value[VALUE_CUM-1] = rate_value (account, FIRST_DATE, CURRENT_DATE);
+ } else {
+   trans.value[PRICE-1] = rate_price (account, trans_date);
+   trans.value[VALUE-1] = rate_value (account, trans_date, trans_date);
+   trans.value[VALUE_CUM-1] = rate_value (account, FIRST_DATE, trans_date);
+ }
+ /* This form allows us to show splits as an increase in shares */
+ trans.value[SHARE-1] = rate_shares (account, FIRST_DATE, trans_date) -
+	                rate_shares (account, FIRST_DATE, trans_date-1);
+ trans.value[COST-1]  = rate_cost (account, trans_date, trans_date);
+ { 
+   YIELD result;
+   rate_yield (account, trans_date, trans_date, &result);
+   trans.value[DISTRIB-1] = result.div;
  }
 
- /* Shares cumulative */
- trans.value[SHARE_CUM-1] += trans.value[SHARE-1];
- if (trans_type == T_SPLIT)
-   trans.value[SHARE_CUM-1] = (trans.value[SHARE_CUM-1] * trans_major) 
-	                      / trans_minor;
 
- /* Cost cumulative */
- trans.value[COST_CUM-1] += trans.value[COST-1];
-
- /* Value cumulative */
- trans.value[VALUE_CUM-1] += trans.value[VALUE-1];
-
- /* Distribution cumulative */
- trans.value[DISTRIB_CUM-1] += trans.value[DISTRIB-1];
+ trans.value[SHARE_CUM-1] = rate_shares (account, FIRST_DATE, trans_date);
+ trans.value[COST_CUM-1]  = rate_cost (account, FIRST_DATE, trans_date);
+ { 
+   YIELD result;
+   rate_yield (account, FIRST_DATE, trans_date, &result);
+   trans.value[DISTRIB_CUM-1] = result.div;
+ }
 
  /* IRR */
  if ( PLOT_ACTIVE(IRRRATE) ) {
@@ -941,130 +885,62 @@ static struct trans_value *calc_trans_values( int account, int transno,
    ** keeps warning from being posted. */
    if (transno == 1) {
      trans.value[IRRRATE-1] = 0.0; 
-     rateClrTrans();
-     rateAddTrans ( transactions, transno);
    } else {
-     rateAddTrans ( transactions, transno );
-     if ( trans_reinvest )
-       trans.value[IRRRATE-1] = rate_IRR( trans.value[SHARE_CUM-1] * trans_nav);
-     else
-       trans.value[IRRRATE-1] = rate_IRR( trans.value[SHARE_CUM-1] * trans_nav +
-		                          trans.value[DISTRIB_CUM-1] ); 
+     rateClrTrans();
+     rate_add_account (account, FIRST_DATE, trans_date);
+     trans.value[IRRRATE-1] = rate_IRR (trans.value[VALUE_CUM-1]  +
+		                        trans.value[DISTRIB_CUM-1]); 
    }
  }
 
  /* TR */
- if ( PLOT_ACTIVE(TRRATE) ) {
-   NAV this;
-   double cost;
+ if (PLOT_ACTIVE(TRRATE)) {
+   double value = trans.value[VALUE_CUM-1] + 
+                  rate_withdrawal (account, FIRST_DATE, trans_date) -
+                  trans.value[COST_CUM-1];
 
-   setNav (&this, NAV_VALUE, &trans_nav);
-   setNav (&this, NAV_DATE, GetTransDate( transactions, transno));
-   cost = account_cost ( account, &this );
-
-   if ( cost == (double)0.0 )
-     trans.value[TRRATE-1] = 0.0;
-   else
-     trans.value[TRRATE-1] = 
-        100.0 * ( (account_value ( account, &this ) + 
-                   account_withdrawal( account, &this ) - cost) / cost );
+   if (trans.value[COST_CUM-1] == (double)0.0) {
+     if (value == 0.0)
+       trans.value[TRRATE-1] = 0.0;
+     else
+       trans.value[TRRATE-1] = (double)USHRT_MAX;
+   } else {
+     trans.value[TRRATE-1] =  (value / trans.value[COST_CUM-1]) * 100.0;
+   }
  }
 
  /* Moving averages */
  if ( PLOT_ACTIVE(PRICE_MAVG) || PLOT_ACTIVE(SHARE_MAVG) || 
       PLOT_ACTIVE(COST_MAVG) || PLOT_ACTIVE(DISTRIB_MAVG) ) {
-   int j;
-
    trans.value[PRICE_MAVG-1] = 0.0;
    trans.value[SHARE_MAVG-1] = 0.0;
    trans.value[COST_MAVG-1] = 0.0;
    trans.value[DISTRIB_MAVG-1] = 0.0;
 
-   if (plot->by_trans) {
-     if (transno >= plot->mov_window) {
-       for (j = transno-plot->mov_window+1; j <= transno; j++) {
-	 int major, minor;
-
-         trans.value[PRICE_MAVG-1] += GetTransNav(transactions, j);
-
-         if ( GetTransType(transactions,j) != T_DIST || 
-	      GetTransFlag(transactions,j,TRANS_REINVEST) )
-           trans.value[SHARE_MAVG-1] += GetTransShares(transactions, j);
-         if ( GetTransType(transactions,j) == T_SELL)
-           trans.value[SHARE_MAVG-1] -= 
-                GetTransLoad(transactions,j)/GetTransNav(transactions,j);
-	 if ( GetTransType(transactions,j) == T_SPLIT) {
-	   major = GetTransSplit (transactions,j,TRANS_MAJOR);
-	   minor = GetTransSplit (transactions,j,TRANS_MINOR);
-           trans.value[SHARE_MAVG-1] = (trans.value[SHARE_MAVG-1] * major)
-		                       / minor;
-	 }
-
-         if ( GetTransType(transactions, j) & (T_BUY | T_SELL) )
-           trans.value[COST_MAVG-1] += GetTransNav(transactions, j) *
-                                       GetTransShares(transactions, j)
-                                       + GetTransLoad(transactions, j);
-         if ( GetTransType(transactions,j) == T_DIST && 
-	     !GetTransFlag(transactions,j,TRANS_REINVEST) )
-           trans.value[COST_MAVG-1] += GetTransNav(transactions, j) *
-                                       -GetTransShares(transactions, j)
-                                       + GetTransLoad(transactions, j);
-
-         if ( GetTransType(transactions, j) & T_DIST )
-           trans.value[DISTRIB_MAVG-1] += GetTransNav(transactions, j) * 
-                                          GetTransShares(transactions, j);
-       }
-       trans.value[PRICE_MAVG-1] /= (float)plot->mov_window;
-       trans.value[SHARE_MAVG-1] /= (float)plot->mov_window;
-       trans.value[COST_MAVG-1] /= (float)plot->mov_window;
-       trans.value[DISTRIB_MAVG-1] /= (float)plot->mov_window;
+   if ((trans_date-plot->daymin) > plot->mov_window*7 ) {
+     float transPerDate;
+     long eDate;
+     long sDate = trans_date - plot->mov_window*7;
+     for (eDate=sDate+1; eDate <= trans_date; eDate++) {
+       /* On last transaction pick up any price points */
+       if (eDate == trans_date && 
+	   trans_date == GetTransLDate (transactions, numTrans))
+         trans.value[PRICE_MAVG-1] += rate_price (account, CURRENT_DATE);
+       else
+         trans.value[PRICE_MAVG-1] += rate_price (account, eDate);
      }
+     trans.value[PRICE_MAVG-1] /= (trans_date-sDate);
 
-   } else { /* by date */
-     if ( trans_date - plot->daymin > plot->mov_window*7 ) {
-       j = transno;
-       while ( j > 0 && (trans_date - GetTransLDate(transactions, j)) 
-                         <= plot->mov_window*7 ) {
-	 int major, minor;
+     trans.value[SHARE_MAVG-1] = rate_shares (account, sDate, trans_date);
+     trans.value[COST_MAVG-1] = rate_cost (account, sDate, trans_date);
+     trans.value[DISTRIB_MAVG-1] = rate_distrib (account, sDate, trans_date);
 
-         trans.value[PRICE_MAVG-1] += GetTransNav(transactions, j);
-
-         if ( GetTransType(transactions,j) != T_DIST || 
-	      GetTransFlag(transactions,j,TRANS_REINVEST) )
-           trans.value[SHARE_MAVG-1] += GetTransShares(transactions, j);
-         if ( GetTransType(transactions,j) == T_SELL)
-           trans.value[SHARE_MAVG-1] -= 
-                GetTransLoad(transactions,j)/GetTransNav(transactions,j);
-	 if ( GetTransType(transactions,j) == T_SPLIT) {
-	   major = GetTransSplit (transactions,j,TRANS_MAJOR);
-	   minor = GetTransSplit (transactions,j,TRANS_MINOR);
-           trans.value[SHARE_MAVG-1] = (trans.value[SHARE_MAVG-1] * major)
-		                       / minor;
-	 }
-
-         if ( GetTransType(transactions, j) & (T_BUY | T_SELL) )
-           trans.value[COST_MAVG-1] += GetTransNav(transactions, j) * 
-                                       GetTransShares(transactions, j)
-                                       + GetTransLoad(transactions, j);
-         if ( GetTransType(transactions,j) == T_DIST && 
-	     !GetTransFlag(transactions,j,TRANS_REINVEST) )
-           trans.value[COST_MAVG-1] += GetTransNav(transactions, j) * 
-                                       -GetTransShares(transactions, j)
-                                       + GetTransLoad(transactions, j);
-
-         if ( GetTransType(transactions, j) == T_DIST)
-           trans.value[DISTRIB_MAVG-1] += GetTransNav(transactions, j) * 
-                                          GetTransShares(transactions, j);
-         j--;
-       }
-       trans.value[PRICE_MAVG-1] /= (float)(transno-j);
-       trans.value[SHARE_MAVG-1] /= (float)(transno-j);
-       trans.value[COST_MAVG-1] /= (float)(transno-j);
-       trans.value[DISTRIB_MAVG-1] /= (float)(transno-j);
-     }
+     transPerDate = (float) rate_datenum(account, sDate, trans_date);
+     trans.value[SHARE_MAVG-1] /= transPerDate;
+     trans.value[COST_MAVG-1]  /= transPerDate;
+     trans.value[DISTRIB_MAVG-1] /= transPerDate;
    }
  }
-
  return (&trans);
 
 }
@@ -1074,35 +950,44 @@ static struct trans_value *calc_trans_values( int account, int transno,
 ** Run through all transactions in an account, picking out the largest and
 ** smallest plot values that are currently active.
 */
-static void max_or_min ( int account, struct attrib *plot ) 
+static int max_or_min ( int account, struct attrib *plot ) 
 {
   PLOT_VAR *graphVar;
+  void   *transactions;
   struct trans_value *trans;
-  int numTrans;
-  int transno, plot_type;
+  int numTrans, transmax;
+  int i, plot_type;
   int err_on = suppressed();
 
   graphVar = graph_attrib ( account );
   getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
+  getAccount( account, ACCOUNT_TRANS, &transactions );
 
   /* No warning messages about calculations when only determining range. 
   ** They're enabled when the drawing routine recalculates them. */
 
   suppress (True);
 
-  for (transno = 1; transno <= numTrans; transno++) {
-    trans = calc_trans_values ( account, transno, plot );
+  transmax = 0;
+  for (i = 1; i <= numTrans; i++) {
+    /* All trans on a day are combined, skip repeats */
+    long trans_date = GetTransLDate ( transactions, i );
+    if (i == 1 || (i > 1 && trans_date > GetTransLDate(transactions, i-1)) ) {
+      trans = calc_trans_values ( account, i, plot );
 
-    for (plot_type = PRICE; plot_type <= NUM_PLOTS; plot_type++)
-      if ( PLOT_ACTIVE(plot_type) && plot_type != CONST ) {
-        MAX_OR_MIN ( trans->value[plot_type-1], plot->scale )
-      }
+      for (plot_type = PRICE; plot_type <= NUM_PLOTS; plot_type++)
+        if ( PLOT_ACTIVE(plot_type) && plot_type != CONST ) {
+          MAX_OR_MIN ( trans->value[plot_type-1], plot->scale )
+        }
+      transmax++;
+    }
   }
  
   /* only off if not previously on */
   if (!err_on)
     suppress (False);
 
+  return (transmax);
 }
 
 
@@ -1115,6 +1000,7 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
   int    x, y;
 
   int    div, perdiv;
+  int    divPixels = PIXELS_PER_VDIV;
 
   struct attrib plot_attrib;
 
@@ -1149,7 +1035,7 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
   plot_attrib.width  -= x_border;  
 
   /* Suck up any extra pixels into title area */
-  t_border += ( (plot_attrib.height-t_border) % PIXELS_PER_VDIV);
+  t_border += ( (plot_attrib.height-t_border) % divPixels);
 
 
   /* 
@@ -1198,16 +1084,11 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
     getAccount( account, ACCOUNT_TRANS, &trans );
     getAccount( account, ACCOUNT_NAV, &navp );
-    if ( by_trans == True ) {
-      plot_attrib.daymin   = 1;
-      plot_attrib.dayrange = numTrans;
-    } else {
-      /* Never have a range of zero, pad each end of plot by one day */
-      plot_attrib.daymin =   GetTransLDate(trans, 1) -1;
-      plot_attrib.dayrange = GetTransLDate(trans, numTrans) - 
+    /* Never have a range of zero, pad each end of plot by one day */
+    plot_attrib.daymin =   GetTransLDate(trans, 1) -1;
+    plot_attrib.dayrange = GetTransLDate(trans, numTrans) - 
                                plot_attrib.daymin +1;
-    }
-    max_or_min ( account, &plot_attrib );
+    plot_attrib.num_pnts = max_or_min ( account, &plot_attrib );
   }
 
   /*
@@ -1237,7 +1118,9 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
   /* Make the range a multiple of the per division value.  */
 
   /* How many divisions and the value per division at "real" range. */
-  div =  (plot_attrib.height - t_border)/ PIXELS_PER_VDIV;
+  div =  (plot_attrib.height - t_border)/ divPixels;
+  div -= (div%5);                /* always have multiple of 5 divisions */
+  divPixels = (plot_attrib.height - t_border) / div;
 
   if (plot_attrib.range == 0)        /* Bad thing #1 range = 0 */
 
@@ -1266,8 +1149,6 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
   /* Real range after truncated math */
   plot_attrib.range = perdiv * div;
 
-  plot_attrib.num_pnts  = numTrans;
-
   /* Where is the zero line */
   plot_attrib.zero =  plot_attrib.height - 
                           ( (int)( (plot_attrib.height-t_border) * 
@@ -1295,7 +1176,7 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
         if (numTrans == 1 && !suppressed()) 
           write_status ("Only one point in this line.", WARN);
 
-        /* Allocate points for XDrawLines */
+        /* Allocate points for XDrawLines, pessimistic number of */
         pnts = (XPoint *) XtRealloc ( (char *)pnts, 
                                       sizeof(XPoint)*(numTrans + 1) );
         if (!pnts) {
@@ -1303,20 +1184,23 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
           return;
         }
 
-        plot_attrib.num_pnts  = numTrans;
-
         /* Loop through each line, generate all lines, place into pnts */
         for (i = 1; i <= NUM_PLOTS; i++) {
+	  int transmax = 0;
 
           if ( PLOT_ACTIVE(i) && i != CONST) {
-
             for (j = 1; j <= numTrans; j++) {
               struct trans_value *t;
 
               trans_date = GetTransLDate ( trans, j );
-              t = calc_trans_values ( account, j, &plot_attrib );
-              calc_xy ( &pnts[j], trans_date, t->value[i-1], &plot_attrib );
+	      if (j==1 || (j > 1 && trans_date > GetTransLDate(trans, j-1)) ) {
+                t = calc_trans_values ( account, j, &plot_attrib );
+		transmax++;
+                calc_xy ( &pnts[transmax], trans_date, 
+			  t->value[i-1], &plot_attrib );
+	      }
             }
+            plot_attrib.num_pnts  = transmax;
 
             /* ok, draw lines onto pixmap */
             plot_xy ( &pnts[1], &plot_attrib, graphVar->attrib[i-1],
@@ -1339,19 +1223,27 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     graphVar = graph_attrib ( account );
     calc_plot_reset();
 
+    /* If there isn't 1 pixel per trans, it's not going to fit */
+    if ( ((int)plot_attrib.width / plot_attrib.num_pnts) == 0 ) {
+      write_status ("Graph width overflow, truncating transactions.", WARN);
+      numTrans = plot_attrib.width;
+    }
     for (i = 1; i <= numTrans; i++) {
       struct trans_value *t;
+      long trans_date = GetTransLDate ( trans, i );
 
-      t = calc_trans_values ( account, i, &plot_attrib );
+      if (i == 1 || (i > 1 && trans_date>GetTransLDate(trans, i-1)) ) {
+        t = calc_trans_values ( account, i, &plot_attrib );
 
-      for (j = PRICE; j <= NUM_PLOTS; j++) {
-        /* 
-        ** THIS ORDER IS IMPORTANT BECAUSE calc_plot_bar ONLY CHECKS
-        ** THE "LESSER" PLOT TYPES FOR OVERLAP
-        */
-        if ( PLOT_ACTIVE (j) )
-          calc_plot_bar ( t->value[j-1], j, &plot_attrib,
-                          Drawing, gc, Drawpixmap );
+        for (j = PRICE; j <= NUM_PLOTS; j++) {
+          /* 
+          ** THIS ORDER IS IMPORTANT BECAUSE calc_plot_bar ONLY CHECKS
+          ** THE "LESSER" PLOT TYPES FOR OVERLAP
+          */
+          if ( PLOT_ACTIVE (j) )
+            calc_plot_bar ( t->value[j-1], j, &plot_attrib,
+                            Drawing, gc, Drawpixmap );
+        }
       }
     } /* end for */
 
@@ -1457,9 +1349,9 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     ** Draw display type and info about NAV change.
     */
     sprintf( status, 
-             "PLOT=> %-11.11s   NAV=> %-7.7s   %30.30s", 
-             (by_trans)?"Transaction":(multiAccount)?"Date Multi":"Date",
-             (isNavChanged(activeAccount(),navp))?"Changed":"Last",
+             "PLOT=> %-13.13s   NAV=> %-10.10s   %30.30s", 
+             (multiAccount)?"Multi-account":"Account",
+             (isNavChanged(activeAccount(),navp))?"Live Quote":"Last",
              (title)?title:NULL ); 
     XtFree (title);
 
@@ -1493,7 +1385,7 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
                    x_border, y,
                    (grid == True)?plot_attrib.width+x_border:x_border+5, y);
 
-      /* Adjust resolution */
+      /* Adjust resolution  - one place we don't use utilCurrOut() */
       if ( (float)plot_attrib.range / (float)plot_attrib.scale > 99.0 ||
            (float)plot_attrib.min   / (float)plot_attrib.scale > 99.0 )
         sprintf( tick, "%5d", next/plot_attrib.scale);
@@ -1513,7 +1405,7 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
                    tick, strlen(tick) );
 
       next += perdiv;
-      y -= PIXELS_PER_VDIV;
+      y -= divPixels;
 
     } while ( div-- > 0 );
 
@@ -1526,15 +1418,18 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
                x_border, 0, x_border, plot_attrib.height);
 
     /* Horizontal ticks */
-    div = plot_attrib.width / PIXELS_PER_HDIV; 
 
     if (by_trans) {
+      div = plot_attrib.width / PIXELS_PER_HDIV; 
       /* if there are less transactions than ticks, reduce ticks */
-      if ( numTrans < div) 
-        div = numTrans;
+      if ( plot_attrib.num_pnts < div) 
+        div = plot_attrib.num_pnts;
       /* start around middle of bar */
       x = x_border + (int)plot_attrib.width/div/2;
     } else {
+      /* Make sure a formatted date fits */
+      strcpy (tick, utilDateOut(plot_attrib.daymin));
+      div = plot_attrib.width / (XTextWidth (small, tick, strlen(tick)) +5);
       if ( plot_attrib.dayrange < div)
         div = plot_attrib.dayrange;
       x = x_border;
@@ -1545,22 +1440,21 @@ void plot ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     ** of the graph is when grids are on.  Increment because loop went one
     ** too far.
     */
-    y += PIXELS_PER_VDIV;
+    y += divPixels;
 
     for ( i = 0; i < div; i++,x += (int)plot_attrib.width/div) {
 
       if (by_trans)
-        sprintf( tick, "%ld", (long) ( (x-x_border) / 
-                 ((int)plot_attrib.width/numTrans)) + plot_attrib.daymin );
+        sprintf( tick, "%ld", (long) ( 
+	      (x-x_border) / ((int)plot_attrib.width/plot_attrib.num_pnts)+1) );
       else {
         /* To gain precision, convert to doubles.  Add 0.5 so values in the
         ** range of x.5 to x.99 round up when truncated by long cast. */
-        long today = (long)(
-                            (double)plot_attrib.daymin + 
-                            (double)i*(double)plot_attrib.dayrange/(double)div +
-                            0.5
+        long today = (long)((double)plot_attrib.daymin + 
+                            (double)i*(double)plot_attrib.dayrange/(double)div 
+                            + 0.5
                            );
-        strcpy ( tick,  daytostr ( today, GetTransDate( trans, 1)) ); 
+        strcpy ( tick,  utilDateOut(today) ); 
       }
 
       XSetForeground( XtDisplay(Drawing), gc, bot_shadow );
