@@ -1,7 +1,7 @@
 "\n",
 NULL,
 "Name\n",
-"Xinvest 2.5.1, a personal finance package for X/Motif.\n",
+"Xinvest 2.6, a personal finance package for X/Motif.\n",
 "\n",
 "Visit the Xinvest/Xquote home page at http://sunsite.auc.dk/xinvest/\n",
 "\n",
@@ -25,9 +25,11 @@ NULL,
 "mutual funds, or your checking ",
 "account.\n",
 "\n",
-"Receive automatic price updates from ",
-"Xquote. On receipt of a price update ",
-"Xinvest will recalculate return information.\n",
+"Receive automatic price and exchange rate updates from ",
+"Xquote.\n",
+"\n",
+"View the output of any tools with currency ",
+"exchange rates applied or not.\n",
 "\n",
 "View various transaction parameters ",
 "such as share price, shares per ",
@@ -35,8 +37,8 @@ NULL,
 "transaction value (at current ",
 "price), dividends, internal and total return, ",
 "and/or cumulative and moving averages of ",
-"the above. Plots are transaction ",
-"based bar or date based x-y charts.\n",
+"the above. Plots are date based ",
+"bar or x-y charts.\n",
 "\n",
 "View overall value weightings of ",
 "accounts in a portfolio. Specify ",
@@ -78,9 +80,11 @@ NULL,
 "\n",
 "options include:\n",
 "\n",
-"-f filename(s)  to load transaction file(s),\n",
-"-help           to print this message.\n",
-"-install        to install a private colormap,\n",
+"-f filename(s)\tto load transaction file(s),\n",
+"-help\t\tto print this message.\n",
+"-install\t\tto install a private colormap,\n",
+"-restore\tfilename\tto restore a saved session,\n",
+"\n",
 "or any valid X toolkit option.\n",
 "\n",
 "\n",
@@ -91,7 +95,6 @@ NULL,
 "\n",
 "Xinvest supports all X toolkit ",
 "options, such as -geometry (see \"man X\"). ",
-"\n",
 "For example, \"Xinvest -geometry 800x600 -bg gray60 -f *.inv\"",
 NULL,
 " Application Resources\n",
@@ -103,10 +106,16 @@ NULL,
 "Xinvest.color0:\n",
 "...\n",
 "Xinvest.color7:\n",
+"Xinvest.colorRed:\n",
+"Xinvest.colorGreen:\n",
+"Xinvest.colorBlack:\n",
+"Xinvest.colorWhite:\n",
+"Xinvest.colorGrey:\n",
 "\n",
 "Plot and asset allocation graphing functions draw ",
-"in the colors specified with these eight resources. ",
-"They may be specified in the same manner ",
+"in the colors specified with the first 8 resources. ",
+"Reports use the latter 5 resources. ",
+"These resources may be specified in the same manner ",
 "and format as any other X color resource specification.\n",
 "\n",
 "Xinvest.fontlist:\n",
@@ -127,8 +136,8 @@ NULL,
 "\n",
 "The large font is used for graph titles, ",
 "reports, and to draw the financial calculator display. ",
-"The small font is used for the scales ",
-"in the graph display and in the asset allocation display.\n",
+"The small font is used for reports, the scales ",
+"in the graph display, and in the asset allocation display.\n",
 "\n",
 "Xinvest.help:\n",
 "\n",
@@ -159,10 +168,14 @@ NULL,
 "OPERATIONS).\n",
 "\n",
 "Once you have a transaction history ",
-"loaded all the tools become active. ",
+"loaded all of the tools become active. ",
 "See specific tool topics for more ",
 "help.\n",
 "\n",
+"Look in the samples directory included ",
+"with the Xinvest distribution for ",
+"examples of transaction histories.\n",
+"\n",
 NULL,
 "Transaction File Format\n",
 "The transaction file is where all ",
@@ -171,8 +184,9 @@ NULL,
 "dividend should be placed here.\n",
 "\n",
 "There are several types of records ",
-"possible: , COMMENT(s), ",
-"PERCENT(s), REINVEST(s), TICKER(s), ",
+"possible: , COMMENT(s), CURRENCY(s), ",
+"PERCENT(s), REINVEST(s), TICKER(s)/",
+"CTICKER(s), ",
 "TITLE(s), and TRANSACTION(s). ",
 "Each is discussed separately.\n",
 "\n",
@@ -288,10 +302,10 @@ NULL,
 "11/20/95 Buy   20.24 15\n",
 "# Dividend of 11.50 reinvested at price 21.71\n",
 "12/31/95 Div   21.71  0.53\n",
-"# All gains are from now on are distributed\n",
+"# All gains from now on are distributed\n",
 "Reinvest NONE\n",
 NULL,
-" Ticker Record\n",
+" Ticker/CTicker Record\n",
 "The ticker record is an optional record. ",
 "It is used to enable automatic price updates ",
 "to be received from Xquote. Xquote reports ",
@@ -300,15 +314,19 @@ NULL,
 "companies, mutual funds, currencies, and some ",
 "other commodities.\n",
 "\n",
+"Cticker is equivalent, but specifies the exchange ",
+"rate to be applied to the account contents.\n",
+"\n",
 "A TICKER record is composed of the following ",
 "fields:\n",
 "\n",
-"KEYWORD TICKER_SYMBOL\n",
+"KEYWORD SYMBOL [MODIFIER[MODIFIER]]\n",
 "\n",
-"The ticker keyword is \"Ticker\" ",
+"The ticker keyword is \"Ticker\" or ",
+"\"CTicker\"",
 "and MUST begin in column one.\n",
 "\n",
-"TICKER_SYMBOL is a one to six character ",
+"SYMBOL is a character ",
 "string defined to represent a publically ",
 "traded company, mutual fund, currency, etc. ",
 "The ticker symbol must be present in the ",
@@ -316,13 +334,35 @@ NULL,
 "to occur. See Xquote online help for more ",
 "information.\n",
 "\n",
-"Multiple tickers are allowable, but ",
-"only the last ticker directive is ",
+"MODIFIER is an optional field allowing ",
+"translation of price updates to the ",
+"price units used in the transaction ",
+"history.  For example, ticker price ",
+"quotes may be in pennies, but your ",
+"transaction history is in dollars. ",
+"Supported modifiers are: \n",
+"\n",
+" /X (invert price quote),\n",
+" *VALUE (multiply by a constant VALUE), or\n",
+" /VALUE (divide by a constant VALUE).\n",
+"\n",
+"VALUE is a decimal notated number ",
+"signifying what constant to operate with. ",
+"Multiple modifiers are supported and MUST ",
+"NOT have any white space between them. ",
+"Modifiers are applied left to right without ",
+"any other precedence rules.\n",
+"\n",
+"Multiple (c)tickers directives are allowable, but ",
+"only the last ticker and cticker directive are ",
 "used.\n",
 "\n",
 "Example ticker records are:\n",
 "ticker JANSX\n",
 "ticker IBM\n",
+"cticker ^XFF /X\t\tFF per USD\n",
+"ticker T *100\t\tconvert to pennies\n",
+"ticker BA ^XBP/X*100\tBP to US pennies\n",
 "\n",
 NULL,
 " Title Record\n",
@@ -341,7 +381,7 @@ NULL,
 "\n",
 "TITLE_TEXT is any text from the ",
 "end of the keyword to the end of ",
-"the line. Whitespace between the ",
+"the line. White space between the ",
 "end of the keyword to the start of ",
 "printable characters is ignored.\n",
 "\n",
@@ -358,7 +398,8 @@ NULL,
 "the following fields:\n",
 "\n",
 "DATE TYPE PRICE [UNITS] [FEE[%]] or\n",
-"DATE TYPE PRICE MAJOR:MINOR\n",
+"DATE TYPE [PRICE] MAJOR:MINOR\n",
+"(for split only)\n",
 "\n",
 "The DATE is the day the transaction ",
 "was effective. The date format is ",
@@ -372,25 +413,32 @@ NULL,
 "\n",
 "The TYPE of a transaction must be ",
 "one of the following key words: \n",
+"\n",
 "BUY,\n",
-"DIV (dividend or interest gain),\n",
-"LTCG (long-term capital gain),\n",
-"STCG (short-term capital gain),\n",
-"PRICE (record price without a transaction),\n",
-"SELL, or\n",
-"SPLIT (record a split or reverse share split)\n",
+"CURRENCY\t(exchange rate),\n",
+"DIV\t(dividend or interest gain),\n",
+"LTCG\t(long-term capital gain),\n",
+"PRICE\t(record price without a transaction),\n",
+"SELL,\n",
+"SPLIT\t(record a split or reverse share split), \n",
+"or STCG\t(short-term capital gain).\n",
 "\n",
 "The PRICE field is the unit price ",
-"of the transaction. It is ",
-"expressed in decimal notation.\n",
+"of the transaction, or exchange rate ",
+"to be used in the case of a CURRENCY ",
+"transaction. It is ",
+"expressed in decimal notation. ",
+"Note that PRICE is optional for the ",
+"SPLIT transaction. If not specified, ",
+"the previous price will be assumed.\n",
 "\n",
 "The UNITS field is the number of ",
 "shares, at cost PRICE per unit, in ",
 "the transaction. It is expressed in ",
 "decimal notation. This value is always ",
 "positive, regardless of the transaction TYPE. ",
-"For the PRICE or SPLIT transaction type, ",
-"there is NO UNITS field.\n",
+"For the PRICE, CURRENCY, or SPLIT transaction ",
+"types, there is NO UNITS field.\n",
 "\n",
 "The MAJOR:MINOR field is the ratio of a share ",
 "split. It is expressed as two integers separated ",
@@ -409,35 +457,56 @@ NULL,
 "\n",
 "A fee may be specified on a BUY ",
 "or DIV transaction as a broker fee or front end load, ",
-"or on a SELL transaction as a back end load. ",
+"or on a SELL transaction as a back end load.\n",
+"\n",
 "The fee is NOT deducted from the amount of shares ",
-"purchased. It is only used to calculate its effect ",
-"on investment return. To specify a fee with no shares ",
-"(eg. annual fee) bought or sold, simply specify 0 shares ",
-"in a buy or sell transaction.\n",
+"purchased on a BUY, but is deducted from the amount ",
+"of shares on a SELL transaction. ",
+"To specify a SELL fee with no shares deducted ",
+"(eg. out-of-pocket annual fee), simply specify a 2nd transaction ",
+"on the same date. This transaction should be a 0 share ",
+"buy with the sell fee specified.\n",
 "\n",
 "Any white space in a transaction record is ",
 "ignored, EXCEPT before the date field.\n",
 "\n",
+NULL,
+"  Example Transaction Records\n",
 "Example transaction records are:\n",
+"# Convert USD to FF\n",
+"11/20/95 Currency 5.15\n",
+"\n",
 "# Buy 15 shares at 20.24\n",
 "11/20/95 Buy   20.24 15\n",
+"\n",
 "# Record a price point\n",
 "11/21/95 Price 20.35\n",
-"# Sell 10 shares at 22.04 per share\n",
+"\n",
+"# Sell 10 shares at 22.04 per share no fee\n",
 "12/21/95 Sell  22.04 10\n",
+"\n",
 "# Dividend of 11.50 reinvested at price 21.71\n",
 "12/31/95 Div   21.71  0.53\n",
+"\n",
 "# Buy 100 shares at 21.52 with 1% front end load\n",
 "1/10/96 Buy    21.53  100.0 1%\n",
-"# Sell 100 shares at 22.03 with fee of 75\n",
+"\n",
+"# Sell 100 shares at 22.03 fee deducted from account\n",
 "2/15/96 Sell   22.03  100.0 75.00\n",
+"\n",
 "# 2 for 1 split and a slight gain in price\n",
 "2/20/96 Split  11.04  2:1\n",
 "\n",
+"# This exchange rate used going forward\n",
+"3/21/96 Currency 5.65\n",
+"\n",
+"# Sell 10 shares at 22.03 out-of-pocket 9.99 fee\n",
+"2/15/96 Sell\t15.43\t10.0 \n",
+"2/15/96 Buy\t15.43\t0.0\t9.99\n",
+"\n",
 NULL,
 " Localized Numbers\n",
-"For localized format numbers, set the ",
+"For localized format input numbers, set the ",
 "LC_NUMERIC environment variable before ",
 "starting Xinvest. For example, ",
 "under HP-UX, \"setenv LC_NUMERIC french\". ",
@@ -465,7 +534,7 @@ NULL,
 "clicking on the \"File\" item on the ",
 "menu bar. Choices selectable on ",
 "the menu are New, Open, Close, Save, ",
-"Save As, and Quit.\n",
+"Save As, Save Session, and Quit.\n",
 "\n",
 "The NEW button creates a new account and ",
 "displays an account template in the transaction ",
@@ -491,10 +560,11 @@ NULL,
 "of the transaction area back into ",
 "the file it was loaded from. The ",
 "originally read file is moved to ",
-"\"filename\".bak. No error checks are ",
+"a backup file (if the backup on save ",
+"preference is enabled). No error checks are ",
 "performed on written files. This button will ",
 "not be selectable if no ",
-"file was loaded or there are no unsaved changes ",
+"file was loaded, or there are no unsaved changes ",
 "in the currently displayed account.\n",
 "\n",
 "The SAVE AS button writes the ",
@@ -509,6 +579,12 @@ NULL,
 "The originally loaded file remains ",
 "as it was.\n",
 "\n",
+"The SAVE SESSION item allows you to save the current configuration ",
+"of Xinvest (loaded accounts, accounts in portfolio, preferences, etc.) ",
+"into a file named .xinvestrc. This session may be restored by ",
+"invoking Xinvest with the '-restore .xinvestrc' option. See INVOCATION and ",
+"SESSION MANAGEMENT for more information.\n",
+"\n",
 "The QUIT button exits from Xinvest. ",
 "The quit function may also be ",
 "activated from the TOOL BUTTON BOX. ",
@@ -568,23 +644,42 @@ NULL,
 "The edit menu is accessed by ",
 "clicking on the \"Edit\" item on the ",
 "menu bar. Choices selectable on ",
-"the menu are Copy, Cut, and Paste.\n",
+"the menu are Copy, Cut, Paste, and Preferences.\n",
 "\n",
 "The edit menu provides access to X-Windows ",
 "clipboard functions, better known as cut ",
 "and paste. When text in the transaction ",
-"window is selected, the cut and copy operations ",
+"window is selected, the CUT and COPY operations ",
 "will be enabled. Cut and copy add the selected ",
 "text to the X-Windows clipboard (close enough ",
 "anyway). In addition, cut removes the selected text from ",
-"the transaction window. Paste places the text ",
+"the transaction window. PASTE places the text ",
 "currently in the clipboard (from Xinvest or any ",
 "other X application) into the transaction window ",
 "at the position of the insertion cursor.\n",
 "\n",
 "The cut and copy functions are disabled if no text ",
-"is selected in the transaction window. Note that you ",
-"may only paste into the transaction window.\n",
+"is selected in the transaction window. Note that ",
+"in this case you may only paste into the transaction window.\n",
+"\n",
+"The PREFERENCES selection displays a dialog where ",
+"you can choose a number of settings that rarely ",
+"change. These include whether Xinvest creates a ",
+"backup copy of your account file on save (and ",
+"what that extension should be), the display output format ",
+"to use for calendar dates, the display output format ",
+"for monetary values, whether exchange rates should ",
+"be used (if present), and the display precision for ",
+"non-monetary values.\n",
+"\n",
+"If one selects 'Localized' format for date or monetary ",
+"display purposes, then the format of these strings are ",
+"supplied by your system (see locale, LC_TIME, LC_MONETARY ",
+"et. al. on your local system help). Selecting a format other ",
+"than localized forces formatting to match the option ",
+"you have selected.  You may change formats as often ",
+"as you wish.  All tools produce output in the last display ",
+"format chosen. See 'LOCALIZATION' for more information.\n",
 NULL,
 " Edit Accelerators\n",
 "Accelerators have been added so that ",
@@ -657,7 +752,8 @@ NULL,
 "mouse enters a button, a line of text will be ",
 "posted describing the time range of that button. ",
 "Built-in time ranges consist of: 1 day, 1 week, 1 month, ",
-"1 quarter (3 months), year to date (YTD), 1 year, since ",
+"1 quarter (3 months), year to date (YTD), 1 year, ",
+"2 year, 3 year, 5 year, 10 year, since ",
 "inception of the account, and custom. You may select as ",
 "many time frames simultaneously as you like.\n",
 "\n",
@@ -712,19 +808,21 @@ NULL,
 NULL,
 "  Options\n",
 "Three options are available for report generation: details, ",
-"annualize, and live. \n",
+"return details, and live window. \n",
 "\n",
-"When 'details' is selected, more information ",
+"When 'details' is selected, more transaction information ",
 "is provided in the report (see Report Display). \n",
 "\n",
-"When 'annualize' is selected, the total return and yield calculations ",
-"will include annualized results (see Report Equations). \n",
+"When 'return details' is selected, more return information ",
+"is provided in the report (see Report Display). \n",
 "\n",
-"When 'live' is selected, the last report window posted (or next ",
-"if none are currently open) will be refreshed by: any price quote, ",
+"When 'live window' is selected, the last report window posted (or next ",
+"if none are currently open) will be refreshed by ",
 "changing the currently displayed account, or by clicking on the ",
-"\"check\" report button. If 'live' is not selected, then report ",
-"windows remain static and to view any report changes it is ",
+"\"check\" report button. If 'live window' is not selected, then ",
+"each time a report is posted a new window is created. You can ",
+"have as many open report windows as you wish. Non-live report ",
+"windows remain static, to view any report changes it is ",
 "necessary to post a new report.\n",
 NULL,
 "  Display\n",
@@ -740,54 +838,26 @@ NULL,
 "* report time frame\n",
 "  If the detail option is on:\n",
 "    * change in value over the time frame.\n",
-"    * change in debit over the time frame.\n",
+"    * change in price over the time frame.\n",
+"    * change in shares over the time frame.\n",
 "    * change in cost over the time frame.\n",
-"    * change in fee over the time frame.\n",
+"    * change in withdrawals over the time frame.\n",
+"    * change in fees over the time frame.\n",
 "  * total return (TR) over the time frame.\n",
 "  * internal rate of return (IRR) over the time frame.\n",
 "  * yield over the time frame.\n",
+"  If the return detail option is on:\n",
+"    * change in value due to price change \n",
+"      over the time frame.\n",
+"    * change in value due to distributions \n",
+"      over the time frame.\n",
 "\n",
-"If annualize is on, total return and yield ",
-"will include the raw return as well as the ",
-"return annualized (see Report Equations).\n",
-NULL,
-"   Localized Currency and Date\n",
-"For localized format dates, set the ",
-"LC_TIME environment variable before ",
-"starting Xinvest. For example, ",
-"under Solaris, \"setenv LC_TIME en_US\". ",
-"With this setting, Xinvest will display dates ",
-"in the MM/DD/YY format. Note that the ",
-"value to set LC_TIME to (and the resultant ",
-"display) is architecture dependent and ",
-"will be different from machine to ",
-"machine. Some architectures do not support ",
-"localized dates (Linux), on such machines a default ",
-"U.S. format is used.\n",
-"\n",
-"For localized format currency, set the ",
-"LC_MONETARY environment variable before ",
-"starting Xinvest. For example, ",
-"under Solaris, \"setenv LC_MONETARY fr\". ",
-"With this setting, Xinvest will display monetary ",
-"values with the French Franc (eg 1.200,37F). ",
-"Note that the value to set LC_MONETARY to (and ",
-"the resultant display) is architecture dependent ",
-"and will be different from machine to machine. ",
-"Some architectures do not support ",
-"localized currency (Linux), on such machines a default ",
-"U.S. format is used.\n",
-"\n",
-"Xinvest's default is not to display with localized ",
-"currency because some architectures don't support ",
-"it yet (Linux). To build Xinvest with this support see the ",
-"README file.\n",
 NULL,
 "  Equations\n",
 "Xinvest reports calculate three return ",
 "values: yield, total return, and internal ",
 "rate of return. Each is described in the following ",
-"sections as well as the method of annualization.\n",
+"sections.\n",
 "\n",
 "Return calculations are effected by the ",
 "reinvest record. See \"Reinvest Record\" ",
@@ -797,13 +867,8 @@ NULL,
 "fees associated with transactions. Fees ",
 "on purchases increase the cost of transactions, ",
 "while fees on sales reduce the number of ",
-"shares remaining in the account. This can be ",
-"considered a bug, as Xinvest should support fees ",
-"more flexibly (either taken from account or ",
-"paid out-of-pocket.\n",
+"shares remaining in the account. \n",
 "\n",
-"Note that return values in excess of 1000% are displayed ",
-"as '>1000%'.\n",
 NULL,
 "   Yield\n",
 "Yield is defined as return generated as a result of ",
@@ -847,17 +912,8 @@ NULL,
 "on the start date is added as a pseudo ",
 "buy transaction.\n",
 "\n",
-NULL,
-"   Annualize\n",
-"Report values are annualized by the following ",
-"equation: ((1.0+rate)**(1.0/years) - 1.0) * 100.0.\n",
-"This is a simple compounding equation where the ",
-"compunding period is derived from the time frame ",
-"of the report period. For example, a one day time ",
-"frame report would have a 'years' value of 1.0/365.0.\n",
-"\n",
 "NOTE THAT SHORT TIME FRAMES CAN GENERATE ",
-"PREPOSTEROUSLY HUGE ANNUALIZED VALUES.\n",
+"PREPOSTEROUSLY HUGE RETURN VALUES.\n",
 NULL,
 " Plot Tool\n",
 "The plot tool provides information ",
@@ -879,7 +935,7 @@ NULL,
 "1. Price per transaction,\n",
 "2. Shares per transaction,\n",
 "3. Cost per transaction,\n",
-"4. Value per transaction (at current NAV),\n",
+"4. Value per transaction,\n",
 "5. Distribution per transaction,\n",
 "6. Internal rate of return,\n",
 "7. Total return, and a\n",
@@ -890,11 +946,13 @@ NULL,
 "above, such as moving average and ",
 "cumulative results.\n",
 "\n",
-"Graphs may be drawn in a bar graph by ",
-"transaction or line graph by date. ",
+"Graphs are drawn by date in bar graph or ",
+"XY line plot. ",
 "As many variables may be selected ",
 "at once as desired.\n",
 "\n",
+"Note that multiple transactions on the same date are combined ",
+"into a single plot bar or point.\n",
 NULL,
 "  Plot Modes - Single or Multi-Account\n",
 "The plot tool has two distinct mechanisms ",
@@ -930,11 +988,11 @@ NULL,
 "\n",
 "Bar graphs, or plotting by transaction, displays a transaction ",
 "history value by drawing a bar (filled rectangle) for each ",
-"transaction in the transaction history. Selected plot ",
+"unique transaction date in the transaction history. Selected plot ",
 "variables are overlaid in each bar such that they are all ",
 "visible at once. Bar plots are DISABLED in multi-account mode.\n",
 "\n",
-"Line graphs, or plotting by date, displays a transaction ",
+"Line graphs display a transaction ",
 "history by dividing up the graph area width into equal ",
 "time segments. A line is drawn from each transaction ",
 "date to the next using the value at that transaction. ",
@@ -950,7 +1008,7 @@ NULL,
 "The zoom default keyboard accelerator is <Ctrl>z.\n",
 "\n",
 "Show Points - by selecting Show Points from ",
-"the option menu, when plotting by date, each ",
+"the option menu, when plotting by line, each ",
 "transaction will be highlighted at the point ",
 "on the line corresponding to the date specified ",
 "in the transaction history. The show points ",
@@ -1011,12 +1069,7 @@ NULL,
 "(date) to the current transaction ",
 "(date).\n",
 "\n",
-"Moving average variables depend on ",
-"the selected graph type, transaction ",
-"or date based. Transaction based ",
-"moving averages are the summation of ",
-"the last N transactions divided by N. ",
-"Date based moving averages are the ",
+"Moving average variables are a ",
 "summation of all transactions within ",
 "the previous N weeks, divided by the ",
 "number of transactions in that period. ",
@@ -1024,12 +1077,24 @@ NULL,
 "average slider. If N is larger than ",
 "the current transaction, no summations ",
 "are started.\n",
+"\n",
+"Note that Xinvest defines a price ",
+"for every date that is queried. ",
+"If no price is defined for a given date, ",
+"the last previous price will be assumed. ",
+"In the case of plotting the price moving ",
+"average this may result in unexpected ",
+"results.  The key to understanding ",
+"the result is to realize Xinvest fills in ",
+"any missing dates with known price values. ",
+"The more defined price/date pairs, the ",
+"more accurate the price moving average plot ",
+"will be.\n",
 NULL,
 "  Localized Date Display\n",
 "Xinvest will display localized dates in ",
-"graphs when plotting by date. See \"Localized ",
-"Currency and Date\" under Return Report ",
-"for more information.\n",
+"graphs when plotting by date. See preferences ",
+"under the \"Edit Menu\" for more information.\n",
 NULL,
 "  Other Notes\n",
 "1. If the values selected for the ",
@@ -1039,15 +1104,8 @@ NULL,
 "be visible.\n",
 "\n",
 "2. The plot display will inform you if ",
-"values are based on a NAV changed in ",
-"the total return screen. If the NAV ",
-"calculator is changed from the value ",
-"of the last transaction in the transaction ",
-"history, that value will be used in value, ",
-"IRR, and TR calculations. A change in the ",
-"calendar currently has no effect on graph ",
-"calculations but will result in a changed NAV ",
-"indication.\n",
+"values are based on a price changed by ",
+"a live quote update.\n",
 "\n",
 "3. If you receive errors about needing ",
 "to change font sizes, see \"Fonts\" under ",
@@ -1135,7 +1193,7 @@ NULL,
 "menu. Other selections from this ",
 "menu include \"Accounts\" which shows ",
 "portfolio percentage based on which ",
-"account its in, and \"Flatten\", which ",
+"account it's in, and \"Flatten\", which ",
 "flattens the heirarchy, showing all ",
 "categories as if they were at the ",
 "top level.\n",
@@ -1365,6 +1423,7 @@ NULL,
 "Edit copy current selection\t\t<Ctrl>c\n",
 "Edit paste current selection\t\t<Ctrl>v\n",
 "Edit cut current selection\t\t<Ctrl>x\n",
+"Edit post preference dialog\t\t<Ctrl>f\n",
 "\n",
 "Account display previous open account\t<Shift><Alt>Tab\n",
 "Account display next open account\t<Alt>Tab\n",
@@ -1395,10 +1454,13 @@ NULL,
 "menu item is selected (see ACCOUNT OPERATIONS). ",
 "Errors detected at this time include:\n",
 "\n",
-"1. incorrect number of fields in title,\n",
-"2. invalid transaction type,\n",
-"3. incorrect number of fields for transaction type,\n",
-"4. transaction dates not sorted earliest to latest.\n",
+"1. malformed or date earlier than previous transaction date,\n",
+"2. invalid parameter for transaction type,\n",
+"3. invalid or unknown transaction type,\n",
+"4. an out of range or negative fee,\n",
+"5. an out of range split,\n",
+"6. incorrect number of fields for transaction type,\n",
+"7. errors in memory allocation.\n",
 "\n",
 "Asset allocation percent lines are checked at ",
 "the time an account is added or removed ",
@@ -1413,12 +1475,39 @@ NULL,
 "Session Management\n",
 "Session management refers (as far as Xinvest is ",
 "concerned) to a mechanism that allows an application ",
-"to save its internal state before being terminated. \n",
+"to save its internal state before being terminated. ",
+"Xinvest supports both an automatic and manual method ",
+"of generating session state files.\n",
 "\n",
+"Xinvest saves the following information in a session ",
+"state file:\n",
+"\n",
+"* the current directory,\n",
+"* all loaded accounts\n",
+"* last live quote update (per account),\n",
+"* all accounts added in asset allocation tool,\n",
+"* the currently displayed account, and \n",
+"* all values from the preference dialog,\n",
+"\n",
+NULL,
+" Manual\n",
+"To manually save the Xinvest internal state you ",
+"may use the 'Save Session' file menu option. This ",
+"option creates (or overwrites) a .xinvestrc file. ",
+"To restore a saved session start Xinvest with the ",
+"-restore option, specifying the full pathname of ",
+"the .xinvestrc file.\n",
+NULL,
+" Automatic\n",
 "Xinvest supports both the X11R5 and X11R6.1 ",
 "session management protocols. For this to work, your ",
 "window manager must support the protocol. \n",
+"Compliant systems include those using X11R6 with the ",
+"X session manager program (xsm) or CDE (both 1.x ",
+"and 2.x).\n",
 "\n",
+NULL,
+" Session File Location\n",
 "You must set an environment variable to tell Xinvest ",
 "where it should hide the saved session files. \n",
 "\n",
@@ -1430,16 +1519,15 @@ NULL,
 "\n",
 "'dir' is a full path to a valid, writable directory.\n",
 "\n",
-"To see if Xinvest thinks your window manager complies, ",
-"look in the message log (see View Operations). ",
-"The message log will contain an informational line ",
-"describing the protocol used (if any). There will be ",
-"no message if your window manager doesn't support ",
-"session management.\n",
+"CDE 1.x users should set SM_SAVE_DIR to '$HOME/.dt/sessions/current'\n",
+"\n",
+"If SM_SAVE_DIR is not defined, saved session files will ",
+"be written into the users home directory (defined by $HOME).\n",
 "\n",
 NULL,
 "Xquote Price Communication\n",
-"Xinvest accepts automatic price quotes from Xquote. ",
+"Xinvest accepts automatic price and/or currency quotes ",
+"from Xquote. ",
 "All that is required is a ticker tape symbol ",
 "in Xinvest that matches one in Xquote (see Ticker ",
 "Record). On each price update, Xquote will search for ",
@@ -1449,18 +1537,36 @@ NULL,
 "quote, generate a return report and verify the ",
 "last price used matches that present in Xquote.\n",
 "\n",
-"Return reports will use automatic price points ",
+"All tools will use automatic price points ",
 "in calculations if the current date is within ",
-"the time frame selected for return calculations. ",
-"This is true for all of the built-in time frames.\n",
+"the time frame selected for calculations. ",
 NULL,
-"Known Problems\n",
-"1. Multiple transactions on one date ",
-"will not plot correctly when displayed ",
-"by date. Multiple points appear on ",
-"that date. Haven't decided whether ",
-"to combine those transaction records ",
-"or detect in graphing routine.\n",
+"Localization\n",
+"For localized format dates, set the ",
+"LC_TIME environment variable before ",
+"starting Xinvest. For example, ",
+"under Solaris, \"setenv LC_TIME en_US\". ",
+"With this setting, Xinvest will display dates ",
+"in the MM/DD/YY format. Note that the ",
+"value to set LC_TIME to (and the resultant ",
+"display) is architecture dependent and ",
+"will be different from machine to ",
+"machine. Some architectures do not support ",
+"localized dates (Linux), on such machines a default ",
+"U.S. format is used.\n",
+"\n",
+"For localized format currency, set the ",
+"LC_MONETARY environment variable before ",
+"starting Xinvest. For example, ",
+"under Solaris, \"setenv LC_MONETARY fr\". ",
+"With this setting, Xinvest will display monetary ",
+"values with the French Franc (eg 1.200,37F). ",
+"Note that the value to set LC_MONETARY to (and ",
+"the resultant display) is architecture dependent ",
+"and will be different from machine to machine. ",
+"Some architectures do not support ",
+"localized currency (Linux), on such machines a default ",
+"U.S. format is used.\n",
 "\n",
 NULL,
 "Reporting Bugs\n",
@@ -1473,14 +1579,9 @@ NULL,
 NULL,
 "Credits\n",
 "Mark Buser\n",
-"931 Greenfield Ave\n",
-"Pittsburgh, PA  15217\n",
+"Pittsburgh, PA\n",
 "(buser@micro.ti.com)\n",
 "\n",
-"Thanks to Amy for letting me use ",
-"the computer when she would rather ",
-"be playing Monkey Island.\n",
-"\n",
 "Xinvest total return calculations ",
 "were inspired by nav.c, author ",
 "unknown. I snarfed it off the net ",
@@ -1501,10 +1602,13 @@ NULL,
 "If you like this program, let me ",
 "know! If you really like it, ",
 "donations are appreciated and will ",
-"go to improving Xinvest.",
+"go to improving Xinvest.\n",
+"\n",
+"If you'd like to work on improving ",
+"this program feel free to contact me.\n",
 NULL,
 "Copyright\n",
-"Copyright \2511995-97 Mark Buser, All Rights Reserved.\n",
+"Copyright \2511995-2000 Mark Buser, All Rights Reserved.\n",
 "\n",
 "Permission is hereby granted to copy ",
 "and freely distribute copies of this ",
