@@ -1,6 +1,6 @@
 /*
-  Xinvest Copyright 1997 Mark Buser,
-  All Rights Reserved.
+  Xinvest Copyright (c)1997-98, 2000
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -20,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 1.3 $ $Date: 1997/08/06 23:21:49 $
+  $Revision: 1.7 $ $Date: 2000/01/12 01:28:26 $
 */
 #ifndef PIXNAME_H
 #define PIXNAME_H
@@ -29,13 +29,14 @@ enum {
        PSTOP, PABOUT, PRETURN, PCALC, PGRAPH, PPORTFOLIO, PEDIT,
        PSAVE, PNEW, POPEN, PPREV, PNEXT, 
        PDAY, PWEEK, PMONTH, PQTR, PYEAR, PYTD, PFIRST, PPICK,
+       P2YEAR, P3YEAR, P5YEAR, P10YEAR,
        PCHECK, PX, 
        PACCT, PACCTS, PFOLD,
        PBAR, PLINE,
        PLAST, PNEXTTRANS, PPREVTRANS,
-       PINFO, PSTIPPLE, PFV, PSFV, PPER, PPV, PRATE, PICON
+       PINFO, PSTIPPLE, PFV, PSFV, PPER, PPV, PRATE, PICON, PTICON
 } Pixmaps;
 
 #define LASTINSENS PLAST
-#define LASTPIXMAP PICON
+#define LASTPIXMAP PTICON
 #endif
