@@ -1,5 +1,5 @@
 /*
-  Xinvest is Copyright 1995-97 Mark Buser,
+  Xinvest Copyright (c)1995-99 Mark Buser,
   All Rights Reserved.
 
   Permission is hereby granted to copy
@@ -20,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.15 $ $Date: 1997/08/16 20:53:31 $
+  $Revision: 2.25 $ $Date: 2000/01/25 22:47:40 $
 */
 
 #include <ctype.h>
@@ -28,11 +28,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#ifdef STRFMON
-#include <monetary.h>
-#endif
 
-#ifndef NeXT
+#if !defined(NeXT) && !defined(__NetBSD__)
 #include <values.h>
 #endif
 
@@ -206,7 +203,6 @@ void portAccount( int account, int what )
 
   double   all_percents = 0.0;
 
-  char     errmsg[512];
   char     *node_error;
 
   getAccount ( account, ACCOUNT_FILENAME, &filename);
@@ -242,7 +238,7 @@ void portAccount( int account, int what )
     /* This is destructive to text, so copy it */
     text = strdup (text);
  
-    value = account_value ( account, NULL );
+    value = rate_value (account, FIRST_DATE, CURRENT_DATE);
 
     front = text;
     end = text + strlen (text);
@@ -303,9 +299,8 @@ void portAccount( int account, int what )
     }
 
     if ( what == PORT_ADD) {
-      if ( all_percents < (double)  99.99999 || 
-           all_percents > (double) 100.00000 ) {
-        sprintf( errmsg, "%s:\nTotal percents (%f) < 100%%.", 
+      if ( abs ((double)100.0 - all_percents) > 1.0E-6 ) { 
+        sprintf( errmsg, "%s:\nTotal percents (%f) != 100%%.", 
                  title, all_percents );
         write_status ( errmsg, INFO );
       }
@@ -328,7 +323,7 @@ void portAccount( int account, int what )
     sprintf ( dummy_str, "Percent 100 %s", rear );
 
     /* 
-    ** Fix title so it doesn't have any . (heirarchy delimiter) or spaces
+    ** Fix title so it doesn't have any '.' (heirarchy delimiter) or ' '
     ** (param delimiter).
     */
     front = strstr ( dummy_str, rear);
@@ -430,25 +425,7 @@ void portAddSubList ( Widget w, XtPointer client_data, XtPointer call_data)
   }
 
   /* Set option menu back to root */
-  {
-    Widget menu;
-    WidgetList buttons;
-    Widget cascade;
-    XmString x_root;
-
-    XtVaGetValues ( Portoptmenu, XmNsubMenuId, &menu, NULL );
-    XtVaGetValues ( menu, XmNchildren, &buttons, NULL );
-    XtVaSetValues ( Portoptmenu,
-                    XmNmenuHistory, buttons[0],
-                    NULL);
-
-    x_root = XmStringCreateLocalized ( "Root" );
-    cascade = XmOptionButtonGadget ( Portoptmenu );
-    XtVaSetValues ( cascade,
-                    XmNlabelString, x_root,
-                    NULL );
-    XmStringFree ( x_root );
-  }
+  setOptionMenu (Portoptmenu, 0);
 
   /* Update percentage tree and display top level to list */
   XtVaSetValues ( Portpercentlist, XmNuserData, &root, NULL );
@@ -496,10 +473,14 @@ void portUpdateDisplay ( )
   local_total = what_value ( node );
 
   while ( current) {
+    char *percentStr;
 
     value = what_value ( current->child );
-    sprintf ( percent, "%-15.15s %6.2f%% %9.2f", 
-              current->child->name, 100.0*value/local_total, value );
+    percentStr = XtNewString (utilCurrOut(100.0*value/local_total, UTILNUM));
+    sprintf ( percent, "%-11.11s %7.7s%% %12.12s", 
+              current->child->name, percentStr,
+	      utilCurrOut(value, UTILCURR) );
+    XtFree (percentStr);
 
     x_percent = XmStringCreateLocalized(percent);
     XmListAddItemUnselected( Portpercentlist, x_percent, 0 );
@@ -508,11 +489,8 @@ void portUpdateDisplay ( )
     current = current->next;
   }
 
-#ifdef STRFMON
-  strfmon ( total_str, 80, "Total Portfolio Value: %n", total_value );
-#else
-  sprintf( total_str, "Total Portfolio Value: $%2.2f", total_value );
-#endif
+  sprintf (total_str, "Total Portfolio Value: %.40s", 
+	   utilCurrOut (total_value, UTILCURR) );
   value_str = XmStringCreateLocalized( total_str ); 
   XtVaSetValues ( Portvaluelabel, XmNlabelString, value_str, NULL );
   XmStringFree ( value_str );
@@ -565,11 +543,6 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     XmStringTable list;
     char *item;
 
-    float value, total = 0.0;
-    float percent;
-    char  wedge[40];
-    char  blurb[40];
-
     int errors = 0;
 
     Dimension height, width;
@@ -638,9 +611,16 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     }
  
     for ( i=0; i < count; i++ ) {
-      XmStringGetLtoR ( list[i], XmFONTLIST_DEFAULT_TAG, &item ); 
-      sscanf ( item, "%s %f%% %*f", &wedge[0], &percent );
-      XtFree ( item );
+      NODE *node;
+      LINK *link;
+      double percent;
+
+      if (i == 0) {
+        XtVaGetValues (Portpercentlist, XmNuserData, &node, NULL);
+        link = node->children;
+      } else
+        link = link->next;
+      percent = (what_value (link->child) / what_value(node)) * 100.0;
 
       /* Move starting angle to 12 o'clock (+90).  This makes picking which
       ** cell to print in _much_ more tractable.
@@ -675,7 +655,7 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     }
 
     /* Calculate size and position of ellipses */
-    major_radius = (int)(0.6 * (int)width /2);
+    major_radius = (int)(0.5 * (int)width /2);
     minor_radius = (int)(0.7 * (int)(height-textHeight) /2);
 
     x = (int)(width - 2* major_radius) / 2;
@@ -882,7 +862,7 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
       /* Where does the text go? Calculate positions of maximum number of
       ** cells of text that can fit.
       */
-      cellheight = small->ascent+small->descent + large->ascent+large->descent;
+      cellheight = small->ascent+small->descent+large->ascent+large->descent;
       cells = (height - (large->ascent + large->descent)) / cellheight;
 
       textLoc = (struct textTable *) XtCalloc (cells, sizeof(struct textTable));
@@ -1006,7 +986,12 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
       }
 
       for (i=0; i < count; i++) {
+        NODE *node;
+        LINK *link;
+        double percent;
 
+        char wedgeN[40];
+        char wedgeP[40];
         int numchars;
         int textx;        /* just a convenience to figure left or right x */
         int texty;
@@ -1014,22 +999,22 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
         /*
         ** Get the text to display
         */
-        XmStringGetLtoR ( list[i], XmFONTLIST_DEFAULT_TAG, &item );
-        /* big assumption, scanf will always find a '%' */
-        sscanf ( item, "%s %f%% %f", &wedge[0], &percent, &value );
-        sprintf ( blurb, "%2.2f %%", percent );
-
-        /* Increment value at this level */
-        total += value;
-        XtFree ( item );
+        if (i == 0) {
+          XtVaGetValues (Portpercentlist, XmNuserData, &node, NULL);
+          link = node->children;
+        } else
+          link = link->next;
+        percent = (what_value (link->child) / what_value(node)) * 100.0;
+        sprintf (wedgeP, "%.6s%%", utilCurrOut (percent, UTILNUM) );
+        sprintf (wedgeN, "%.13s", link->child->name);
 
         if (sliceLoc[i].slot != -1) {
           /* Draw the user supplied name */
-          XSetFont ( XtDisplay (Drawing), gc, large->fid );
-          numchars = strlen ( wedge );
-          textWidth = XTextWidth ( large, wedge, numchars );
-          while ( textWidth > (x - 20) )
-            textWidth = XTextWidth ( large, wedge, --numchars);
+          XSetFont (XtDisplay (Drawing), gc, large->fid);
+          numchars = strlen (wedgeN);
+          textWidth = XTextWidth (large, wedgeN, numchars);
+          while (textWidth > (x - 20))
+            textWidth = XTextWidth (large, wedgeN, --numchars);
 
           if (sliceLoc[i].onleft)
             textx = textLoc[sliceLoc[i].slot].left_x;
@@ -1041,28 +1026,28 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
 #endif
           texty = textLoc[sliceLoc[i].slot].y;
 
-          XSetForeground ( XtDisplay(Drawing), gc, bot_shadow );
-          XDrawString ( XtDisplay (Drawing), Drawpixmap, gc,
-                        textx +1, texty +1, wedge, numchars );
-          XSetForeground ( XtDisplay(Drawing), gc, foreground );
-          XDrawString ( XtDisplay (Drawing), Drawpixmap, gc,
-                        textx, texty, wedge, numchars );
+          XSetForeground (XtDisplay(Drawing), gc, bot_shadow);
+          XDrawString (XtDisplay (Drawing), Drawpixmap, gc,
+                       textx +1, texty +1, wedgeN, numchars);
+          XSetForeground (XtDisplay(Drawing), gc, foreground);
+          XDrawString (XtDisplay (Drawing), Drawpixmap, gc,
+                       textx, texty, wedgeN, numchars);
 
-          /* Draw the user supplied percentage */
-          XSetFont ( XtDisplay (Drawing), gc, small->fid );
-          numchars = strlen ( blurb );
-          textWidth = XTextWidth ( small, blurb, numchars );
-          while ( textWidth > (x - 20) )
-            textWidth = XTextWidth ( small, blurb, --numchars);
+          /* Draw the percentage */
+          XSetFont (XtDisplay (Drawing), gc, small->fid);
+          numchars = strlen (wedgeP);
+          textWidth = XTextWidth (small, wedgeP, numchars);
+          while (textWidth > (x - 20))
+            textWidth = XTextWidth (small, wedgeP, --numchars);
 
-          XSetForeground ( XtDisplay(Drawing), gc, bot_shadow );
-          XDrawString ( XtDisplay (Drawing), Drawpixmap, gc,
-                        textx +1, texty + large->descent + small->ascent +1,
-                        blurb, numchars );
-          XSetForeground ( XtDisplay(Drawing), gc, foreground );
-          XDrawString ( XtDisplay (Drawing), Drawpixmap, gc,
-                        textx, texty + large->descent + small->ascent,
-                        blurb, numchars );
+          XSetForeground (XtDisplay(Drawing), gc, bot_shadow);
+          XDrawString (XtDisplay (Drawing), Drawpixmap, gc,
+                       textx +1, texty + large->descent + small->ascent +1,
+                       wedgeP, numchars);
+          XSetForeground ( XtDisplay(Drawing), gc, foreground);
+          XDrawString (XtDisplay (Drawing), Drawpixmap, gc,
+                       textx, texty + large->descent + small->ascent,
+                       wedgeP, numchars);
         }
       }
 
@@ -1079,24 +1064,25 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
     XSetFont ( XtDisplay (Drawing), gc, small->fid );
     {
       char intro[] = "Value at '";
+      char trail[] = "' - ";
+      char *value;
       char *line;
       NODE *node;
       char **levels = NULL;
       int numlevels = 0;
       int numbytes = 0;  /* How many chars in the assembled string */
 
+      XtVaGetValues (Portpercentlist, XmNuserData, &node, NULL);
+      value = utilCurrOut (what_value(node), UTILCURR);
+
+      numbytes = strlen (intro) +1;
+      numbytes += strlen (trail);
+      numbytes += strlen (value);
+
       /* Assemble the line.  As we're traveling up, the names are processed
       ** backwards, so the first name printed is the last name found.  */
 
-#ifdef STRFMON  /* Level value */
-      strfmon ( blurb, 20, "' - %.2n", total );
-#else
-      sprintf ( blurb, "' - $%.2f", total );
-#endif
-      numbytes += strlen (blurb);
-
       /* Level names */
-      XtVaGetValues ( Portpercentlist, XmNuserData, &node, NULL );
       while (node) {
 	levels = (char **) XtRealloc ( (char *)levels, 
                                        (numlevels+1) * sizeof(char **) );
@@ -1107,17 +1093,19 @@ int pie ( Widget Drawing, Pixmap Drawpixmap, GC gc )
 	else
           break;
       }
-      numbytes += strlen (intro) +1;
 
       /* Create single string and copy in all of the fields in forward order */
-      line = XtMalloc ( numbytes * sizeof (char) );
+      line = XtMalloc (numbytes * sizeof (char));
       strcpy (line, intro);
       while (numlevels--) {
 	strcat (line, levels[numlevels]);
 	if (numlevels)
   	  strcat (line, ".");
       }
-      strcat (line, blurb);
+      XtFree ((char *)levels);
+
+      strcat (line, trail);
+      strcat (line, value);
 
       textWidth = XTextWidth ( small, line, strlen ( line ) );
       x = (width - textWidth) / 2;
