@@ -1,5 +1,6 @@
 /*
-  Xinvest is copyright 1995,.1996 by Mark Buser.
+  Xinvest Copyright (c)1995-96, 2000 
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -19,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.19 $ $Date: 1997/09/20 17:02:41 $
+  $Revision: 2.38 $ $Date: 2000/02/04 00:38:16 $
 */
 
 /*  rate of return of a portfolio	*/
@@ -32,13 +33,47 @@
 #include <Xm/Xm.h>
 
 #include "account.h"
+#include "calendar.h"
 #include "drawing.h"
 #include "nav.h"
+#include "pref.h"
 #include "rate.h"
 #include "trans.h"
 #include "status.h"
 #include "xutil.h"
 
+
+/* Convert FIRST_DATE, LAST_DATE, and CURRENT_DATE into real dates */
+long convertDate (int account, long date)
+{
+  void *trans;
+  int numTrans;
+
+  getAccount (account, ACCOUNT_TRANS, &trans);
+  getAccount (account, ACCOUNT_NUM_TRANS, &numTrans);
+
+  if (trans == NULL)
+    return 0L;        /* at least we'll notice this */
+
+  if (date == LAST_DATE) 
+    return GetTransLDate (trans, numTrans); 
+
+  else if (date == FIRST_DATE)
+    return GetTransLDate (trans, 1); 
+
+  else if (date == CURRENT_DATE) {
+    char datebuf[20];
+    time_t t = time ((time_t *)NULL);
+    struct tm *today = localtime (&t);
+
+    strftime (datebuf, 20, "%m/%d/%Y", today);
+    return (calStrtoL (datebuf));
+
+  } else
+    return date;
+}
+
+
 /*  
 **  strtoday - string into day number 
 **  Convert "MM/DD/YY", "MM/DD/YYYY",  or "MMDDYY" into # of days using 
@@ -101,65 +136,6 @@ middle:	    dd = ddend + 1;
 #undef YEAR
 }
 
-/*
-** Given we know the long and string of p, calculate the string of date.
-** We know it must be later than p.
-*/
-char *daytostr (long date, char *p )
-{
-  int month;
-  int day;
-  int year;
-
-  struct tm date_tm;
-
-  char year_char[5];
-  static char try[20];
-
-  /* extract date from transaction record */
-  p += 2;
-  if ( *p == '/' )   /* skip if present */
-    p++;
-  p += 2;
-  if ( *p == '/' )   /* skip if present */
-    p++;
-
-  /* Assume \0 is present in p */
-  strcpy( year_char, p );
-
-  /* get int versions */
-  month = 1;
-  day =   1;
-  year =  atoi ( year_char );
-
-  sprintf( try, "%2.2d/%2.2d/%2.2d", month, day, year);
-
-  while ( strtoday ( try ) <=  date ) {
-    year++;
-    sprintf( try, "%2.2d/%2.2d/%2.2d", month, day, year);
-  }
-  year--;
-  sprintf( try, "%2.2d/%2.2d/%2.2d", month, day, year);
-
-  while ( strtoday ( try ) <=  date && month <= 12 ) {
-    month++;
-    sprintf( try, "%2.2d/%2.2d/%2.2d", month, day, year);
-  }
-  month--;
-  sprintf( try, "%2.2d/%2.2d/%2.2d", month, day, year);
-
-  day = date - strtoday( try ) +1;
-  sprintf( try, "%2.2d %2.2d %2.2d", month, day, year);
-
-  /* Convert to internationalized format */
-  if (year > 1000)
-    strptime ( try, "%m %d %Y", &date_tm);
-  else
-    strptime ( try, "%m %d %y", &date_tm);
-  strftime ( try, 10, "%x", &date_tm);
-  return ( try );
-}
-
 static double *deposits = NULL;   /* value of deposit */
 static long *dates = NULL;        /* date of deposit */
 static int  ndep = 0;             /* num deposits */
@@ -175,7 +151,7 @@ void rateClrTrans ()
   IRRmaxday = 0;
 }
 
-void rateAddValue(double val, long day)
+static void rateAddValue(double val, long day)
 {
   deposits = (double *) XtRealloc( (char *)deposits, sizeof(double)*(ndep+1));
   dates  =   (long *) XtRealloc( (char *) dates, sizeof(long)*(ndep+1));
@@ -188,12 +164,12 @@ void rateAddValue(double val, long day)
   ndep++; 
 }
 
-void rateAddTrans( TRANS *trans, int transno)
+void rateAddTrans( TRANS *trans, int transno, double exch)
 {
   int type = GetTransType (trans, transno);
   long day = GetTransLDate( trans, transno );
 
-  if ( type & (T_BUY | T_SELL)) { 
+  if ( type==T_BUY || type==T_SELL) {
     deposits = (double *) XtRealloc( (char *)deposits, sizeof(double)*(ndep+1));
     dates  =   (long *) XtRealloc( (char *) dates, sizeof(long)*(ndep+1));
     if ( deposits == NULL || dates == NULL) {
@@ -205,16 +181,16 @@ void rateAddTrans( TRANS *trans, int transno)
     ** Load is added on a buy because this is what it cost, shares+fee.
     */
     if (type == T_BUY) 
-      deposits[ndep] = GetTransNav( trans,transno ) 
-    	               * GetTransShares( trans, transno) 
-		       + GetTransLoad(trans,transno);
+      deposits[ndep] = (GetTransNav( trans,transno ) * exch  
+    	                * GetTransShares( trans, transno)) 
+		       + (GetTransLoad(trans,transno) * exch);
     /* 
     ** Load is NOT subtracted here since this is all we really got out. Load on
     ** sales work into the IRR calculation via current value, which is less
     ** when there is a fee. 
     **/
     else if (type == T_SELL) 
-      deposits[ndep] = GetTransNav( trans,transno )
+      deposits[ndep] = GetTransNav( trans,transno ) * exch 
 	               * GetTransShares( trans, transno);
 
     dates[ndep] = day;
@@ -233,45 +209,11 @@ void rateClrAccount ()
 }
 
 
-/* Add this account to rate of return calculation input */
-void rateAddAccount ( int account, NAV *nav)
-{
-  char err_msg[132];
-  long endDate = navToLDate ( nav );
-
-  int transno;
-  void *trans;
-  int  numTrans;
-
-  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
-  getAccount( account, ACCOUNT_TRANS, &trans );
-
-  /* If the NAV is too early, tell the user */
-  if ( endDate < GetTransLDate(trans, 1) ) {
-    if (!suppressed()) {
-      char *name = createAccountName (account);
-      sprintf ( err_msg, 
-                "%s:\nSpecified NAV date is earlier than\nfirst transaction.",
-                name );
-      write_status ( err_msg, ERR );
-      XtFree (name);
-    }
-    return;
-  }
-
-  /* Add transactions to deposits until end or we reach user specified end */
-  for (transno = 1; transno <= numTrans; transno++) {
-    if ( GetTransLDate(trans, transno) > endDate )
-      break;
-    rateAddTrans (trans, transno);
-  }
-}
-
 void rate_add_account (int account, long sdate, long edate)
 {
-  int transno;
   void *trans;
   int  numTrans;
+  int transno;
 
   long start, end;
 
@@ -300,11 +242,12 @@ void rate_add_account (int account, long sdate, long edate)
   }
 
   for (transno = 1; transno <= numTrans; transno++) {
-    if ( GetTransLDate (trans, transno) < start )
+    long date = GetTransLDate (trans, transno);
+    if ( date < start )
       continue;
-    if ( GetTransLDate (trans, transno) > end )
+    if ( date > end )
       break;
-    rateAddTrans (trans, transno);
+    rateAddTrans (trans, transno, rate_exch(account, date));
   }
 
 }
@@ -361,34 +304,6 @@ double rate_IRR ( double curtot )
 }
 
 
-double account_fee( int account, NAV *nav )
-{
-  int i;
-  double load = 0.0;
-  long maxday = 0;
-
-  int numTrans;
-  void *trans;
-
-  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
-  getAccount( account, ACCOUNT_TRANS, &trans );
-
-  if ( nav != NULL )
-    maxday = navToLDate( nav );
-  else
-    maxday = GetTransLDate(trans, numTrans);
-
-  for ( i=1; i <= numTrans; i++) {
-    if ( GetTransLDate(trans, i) > maxday ) 
-      /* user specified date less then some number of transactions */
-      break;
-
-    load += GetTransLoad (trans, i);
-  }
-
-  return (load);
-}
-
 double rate_fee( int account, long sdate, long edate )
 {
   int i;
@@ -413,65 +328,216 @@ double rate_fee( int account, long sdate, long edate )
     end = edate;
 
   for ( i=1; i <= numTrans; i++) {
-
-    if ( GetTransLDate(trans, i) < start ) 
+    long date = GetTransLDate (trans, i);
+    if ( date < start ) 
       continue;
-    if ( GetTransLDate(trans, i) > end ) 
+    if ( date > end ) 
       break;
 
-    load += GetTransLoad (trans, i);
+    load += (GetTransLoad (trans, i) * rate_exch(account, date));
+  }
+  return (load);
+}
+
+
+/* How many dates have transactions with the specified range */
+double rate_datenum( int account, long sdate, long edate )
+{
+  int numTrans;
+  void *trans;
+
+  long start, end;
+  int i, dateTrans = 0;
+
+  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
+  getAccount( account, ACCOUNT_TRANS, &trans );
+
+  if (sdate == FIRST_DATE)
+    start = GetTransLDate( trans, 1 );
+  else
+    start = sdate;
+
+  if (edate == LAST_DATE)
+    end = GetTransLDate( trans, numTrans );
+  else
+    end = edate;
+
+  for (i=1; i <= numTrans; i++) {
+    if (GetTransLDate(trans, i) < start) 
+      continue;
+    
+    if (GetTransLDate(trans, i) > end) 
+      break;
+
+    dateTrans++;
   }
 
-  return (load);
+  return (dateTrans);
+}
+
+
+/* Sometimes we need just the exchange rate, not only adjusted price */
+double rate_exch( int account, long date )
+{
+  int i;
+  double exchg = 1.0;
+
+  int numTrans;
+  void *trans;
+
+  long end;
+  int  latestETrans = 0;
+
+  if (prefGetUseCurr()==0)  /* exchange rate use is off */
+    return (exchg);
+
+  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
+  getAccount( account, ACCOUNT_TRANS, &trans );
+
+  if (date == FIRST_DATE)
+    end = GetTransLDate( trans, 1 );
+  else if (date == LAST_DATE)
+    end = GetTransLDate( trans, numTrans );
+  else if (date == CURRENT_DATE)
+    end = convertDate(account, date);
+  else
+    end = date;
+
+  /* Find last trans before end date */
+  for (i=1; i <= numTrans; i++) {
+    long nextDate;
+    int type;
+	    
+    nextDate = GetTransLDate (trans, i);
+    type = GetTransType(trans, i);
+
+    /* If we have a exchange rate within range, then done */
+    if (nextDate <= end && latestETrans != 0) 
+      break;
+
+    /* Otherwise look for the last exchange rate */
+    if (type == T_CURR) /* latest exchange rate date */
+      latestETrans = i;
+  }
+
+  /* Pending exchange quote? If not enabled or not available,   */
+  /* use last exchange rate within date range.                  */
+  {
+    NAV *navp;
+    float val;
+    getAccount (account, ACCOUNT_CURRENCY, &navp);
+    if (latestETrans > 0)
+      exchg = GetTransCurrency (trans, latestETrans);
+    if (navp && isNavChanged(account, navp)) {
+      if ((latestETrans == 0 || (latestETrans > 0 &&
+	   navToLDate(navp) > GetTransLDate(trans, latestETrans))) &&
+	  navToLDate(navp) <= end ) {
+        getNav (navp, NAV_VALUE, &val);
+        exchg = (double)val;
+      }
+    }
+  }
+
+  return (exchg);
+}
+
+
+
+double rate_price( int account, long date )
+{
+  int i;
+  double price = 0.0;
+  double exchg = 1.0;
+  double split = 1.0;
+
+  int numTrans;
+  void *trans;
+
+  long end;
+  int  latestPTrans = 0, latestETrans = 0;
+
+  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
+  getAccount( account, ACCOUNT_TRANS, &trans );
+
+  if (date == FIRST_DATE)
+    end = GetTransLDate( trans, 1 );
+  else if (date == LAST_DATE)
+    end = GetTransLDate( trans, numTrans );
+  else if (date == CURRENT_DATE)
+    end = convertDate(account, date);
+  else
+    end = date;
+
+  /* Find last trans before end date */
+  for (i=1; i <= numTrans; i++) {
+    long nextDate;
+    int type;
+	    
+    nextDate = GetTransLDate (trans, i);
+    type = GetTransType(trans, i);
+
+    /* Process prices only within date range or get the next possible price */
+    if (nextDate <= end || (nextDate>end && latestPTrans == 0)) 
+      if (type != T_CURR) /* latest price date */
+        latestPTrans = i;
+
+    /* Process exchange rates within date range or get the next possible */
+    if (nextDate <= end || (nextDate>end && latestETrans == 0)) 
+      if (type == T_CURR) /* latest exchange rate date */
+        latestETrans = i;
+
+    /* We have to check all forward transactions to find any splits */
+    if ( nextDate > end && type == T_SPLIT )
+      /* Note inversion, price is effected opposite of shares by split */
+      split = (split * GetTransSplit(trans,i,TRANS_MINOR)) 
+	       / GetTransSplit(trans,i,TRANS_MAJOR);
+  }
+
+  /* Pending price point? If not use last NAV within date range. */
+  {
+    NAV *navp;
+    float val = 0.0;
+    getAccount (account, ACCOUNT_NAV, &navp);
+    /* 
+    ** Price point must be later than any existing trans and no later than
+    ** end date.
+    */
+    if (latestPTrans > 0)
+      price = GetTransNav (trans, latestPTrans) * split;
+    if (navp && isNavChanged (account, navp)) {
+      if (latestPTrans > 0 &&
+          navToLDate(navp) > GetTransLDate(trans, latestPTrans) &&
+	  navToLDate(navp) <= end) { 
+        getNav (navp, NAV_VALUE, &val);
+        price = (double)val;
+      }
+    }
+  }
+
+  /* Pending exchange quote? If not enabled or not available,   */
+  /* use last exchange rate within date range.                  */
+  if (prefGetUseCurr()) {
+    NAV *navp;
+    float val;
+    getAccount (account, ACCOUNT_CURRENCY, &navp);
+    if (latestETrans > 0)
+      exchg = GetTransCurrency (trans, latestETrans);
+    if (navp && isNavChanged(account, navp)) {
+      if ((latestETrans == 0 || (latestETrans > 0 &&
+	   navToLDate(navp) > GetTransLDate(trans, latestETrans))) &&
+	  navToLDate(navp) <= end ) {
+        getNav (navp, NAV_VALUE, &val);
+        exchg = (double)val;
+      }
+    }
+  }
+
+  return (price*exchg);
 }
 
 
 /* How many shares are in the account, taking into consideration dividend
 ** reinvestment (or not), load on sales, and splits. */
-double account_shares( int account, NAV *nav )
-{
-  int i;
-  double shares = 0.0;
-  long	 maxday = 0;
-
-  int numTrans;
-  void *trans;
-  int type;
-  int reinvest;
-
-  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
-  getAccount( account, ACCOUNT_TRANS, &trans );
-
-  if ( nav != NULL )
-    maxday = navToLDate( nav );
-  else
-    maxday = GetTransLDate(trans, numTrans);
-
-  for ( i=1; i <= numTrans; i++) {
-    if ( GetTransLDate(trans, i) > maxday ) 
-      /* user specified date less then some number of transactions */
-      break;
-
-    /* add up all shares owned. */
-    type = GetTransType(trans,i);
-    reinvest = GetTransFlag ( trans, i, TRANS_REINVEST );
-
-    /* shares are neg for T_SELL. divs only if reinvest on */
-    if ( type != T_DIST || reinvest )
-      shares += GetTransShares(trans, i);
-
-    /* possible load on sale */
-    if ( type == T_SELL )
-      shares -= GetTransLoad(trans,i) / GetTransNav(trans,i);
-
-    if ( type == T_SPLIT )
-      shares = ( shares * GetTransSplit(trans,i,TRANS_MAJOR)) 
-	       / GetTransSplit(trans,i,TRANS_MINOR);
-  }
-
-  return ( shares );
-}
-
 double rate_shares( int account, long sdate, long edate )
 {
   int i;
@@ -493,6 +559,8 @@ double rate_shares( int account, long sdate, long edate )
 
   if (edate == LAST_DATE)
     end = GetTransLDate( trans, numTrans );
+  else if (edate == CURRENT_DATE)
+    end = convertDate(account, edate);
   else
     end = edate;
 
@@ -524,36 +592,58 @@ double rate_shares( int account, long sdate, long edate )
   return ( shares );
 }
 
-
-/* What are the current shares worth at current price */
-double account_value ( int account, NAV *nav )
+double rate_esop_cost (int account, long sdate, long edate)
 {
   double  curtot = 0.0;
+  double  exchg = 1.0;
+  int	  i;
+
   int     numTrans;
   void    *trans;
 
+  long    start, end;
+
   getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
   getAccount( account, ACCOUNT_TRANS, &trans );
 
-  curtot = account_shares ( account, nav );
-
-  if ( nav != NULL )
-    curtot *= nav->value;
+  if (sdate == FIRST_DATE)
+    start = GetTransLDate( trans, 1 );
   else
-    curtot *= GetTransNav(trans, numTrans);
+    start = sdate;
 
+  if (edate == LAST_DATE)
+    end = GetTransLDate( trans, numTrans );
+  else if (edate == CURRENT_DATE)
+    end = convertDate(account, edate);
+  else
+    end = edate;
+
+
+  for (i = 1; i <= numTrans; i++) {
+    long date = GetTransLDate (trans, i);
+    if (date < start)
+      continue;
+
+    if (date > end)
+      break;
+
+    /* add up cost of ESOP shares only */
+    if (GetTransType(trans, i) == T_ESOP) {
+      exchg = rate_exch (account, date);
+      curtot += ( (GetTransShares(trans, i) * GetTransNav(trans, i) * exchg) + 
+                  (GetTransLoad (trans, i) * exchg) ); 
+    }
+  }
   return (curtot);
 }
 
+
 double rate_value ( int account, long sdate, long edate )
 {
   double  curtot = 0.0;
   int     numTrans;
   void    *trans;
 
-  int     i;
-  long    latestDate = 0;
-
   long    start, end;
 
   getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
@@ -569,80 +659,21 @@ double rate_value ( int account, long sdate, long edate )
   else
     end = edate;
 
-  curtot = rate_shares (account, start, end);
-
-  /* Find last trans before end date */
-  for (i=1; i <= numTrans; i++) {
-    long nextDate = GetTransLDate (trans, i);
-
-    if (nextDate < start) 
-      continue;
-    
-    if (nextDate > end) 
-      break;
-
-    if (nextDate == latestDate)
-      continue;
-
-    latestDate = nextDate;
-  }
-
-  /* Do we have a pending price point? If not use last NAV within date range. */
-  {
-    NAV *navp;
-    float val = 0.0;
-    getAccount (account, ACCOUNT_NAV, &navp);
-    /* 
-    ** Price point must be later than any existing trans and no later than
-    ** end date.
-    */
-    if (navp && navToLDate(navp) > latestDate && navToLDate(navp) <= end) { 
-      getNav (navp, NAV_VALUE, &val);
-      curtot *= (double)val;
-    } else if (i-1 > 0)
-      curtot *= GetTransNav (trans, i-1);
-  }
+  curtot = (rate_shares (account, start, end) * rate_price (account, end)) 
+	   - rate_esop_cost(account, start, end);
 
   return (curtot);
 }
 
 
 /* How much have we spent on shares including load */
-double account_cost ( int account, NAV *nav )
-{
-  long	  maxday = 0;
-  double  curtot = 0.0;
-  int	  i;
-
-  int     numTrans;
-  void    *trans;
-
-  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
-  getAccount( account, ACCOUNT_TRANS, &trans );
-
-  if ( nav != NULL )
-    maxday = navToLDate( nav );
-  else
-    maxday = GetTransLDate(trans, numTrans);
-
-  for (i = 1; i <= numTrans; i++) {
-
-    /* user specified date less then some number of transactions */
-    if ( GetTransLDate(trans, i) > maxday)
-      break;
-
-    /* add up all shares owned for current cost, factor in load  */
-    if ( GetTransType(trans, i) == T_BUY)
-      curtot += (GetTransShares(trans, i) * GetTransNav(trans, i)
-                + GetTransLoad (trans, i)); 
-  }
-
-  return (curtot);
-}
-
 double rate_cost ( int account, long sdate, long edate )
 {
+#if 0
+  double  sold_val = 0.0;
+#endif
   double  curtot = 0.0;
+  double  exchg = 1.0;
   int	  i;
 
   int     numTrans;
@@ -665,65 +696,52 @@ double rate_cost ( int account, long sdate, long edate )
 
 
   for (i = 1; i <= numTrans; i++) {
-
-    if ( GetTransLDate(trans, i) < start)
+    long date = GetTransLDate (trans, i);
+    if (date < start)
       continue;
 
-    if ( GetTransLDate(trans, i) > end)
+    if (date > end)
       break;
 
-    /* add up all shares owned for current cost, factor in load  */
-    if ( GetTransType(trans, i) == T_BUY)
-      curtot += (GetTransShares(trans, i) * GetTransNav(trans, i)
-                + GetTransLoad (trans, i)); 
-  }
+#if 0
+    if (GetTransType(trans, i) == T_BUY) {
+      double cur_val = GetTransShares(trans, i) * GetTransNav(trans, i);
 
+      /* If we've bought more than sold, increase cost */
+      if (cur_val > sold_val) {
+        curtot += (cur_val - sold_val);
+	sold_val = 0.0;
+
+      } else 
+        sold_val -= cur_val;
+    }
+
+    else if ( GetTransType(trans, i) == T_SELL) 
+      sold_val -= GetTransShares(trans, i) * GetTransNav(trans, i);
+
+#else
+    /* add up all shares owned for current cost, factor in load  */
+    if ( GetTransType(trans, i) == T_BUY) {
+      exchg = rate_exch (account, date);
+      curtot += ( (GetTransShares(trans, i) * GetTransNav(trans, i) * exchg) + 
+                  (GetTransLoad (trans, i) * exchg) ); 
+    }
+#endif
+  }
   return (curtot);
 }
 
+
 /* How much money came out of the account not including load which just
 ** evaporated. */
-double account_withdrawal( int account, NAV *nav )
-{
-  int i;
-  double withdraw = 0.0;
-  long	  maxday = 0;
-
-  int numTrans;
-  void *trans;
-  int reinvest;
-
-  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
-  getAccount( account, ACCOUNT_TRANS, &trans );
-
-  if ( nav != NULL )
-    maxday = navToLDate( nav );
-  else
-    maxday = GetTransLDate(trans, numTrans);
-
-  for ( i=1; i <= numTrans; i++) {
-    if ( GetTransLDate(trans, i) > maxday ) 
-      /* user specified date less then some number of transactions */
-      break;
-
-    if ( GetTransType(trans, i) == T_SELL ) 
-      /* - since T_SELL shares are negative. */
-      withdraw += (-GetTransShares(trans, i) * GetTransNav(trans, i));
-
-    /* divs only if reinvest off. */
-    reinvest = GetTransFlag (trans, i, TRANS_REINVEST);
-    if ( GetTransType(trans,i) == T_DIST && !reinvest )
-      withdraw += GetTransShares(trans, i) * GetTransNav(trans, i);
-  }
-
-  /* withdraw is positive for any sales or div distributions */
-  return ( withdraw );
-}
-
 double rate_withdrawal( int account, long sdate, long edate )
 {
-  int i;
+#if 0
+  double bought_val = 0.0;
+#endif
   double withdraw = 0.0;
+  double exchg = 1.0;
+  int i;
 
   int numTrans;
   void *trans;
@@ -745,62 +763,50 @@ double rate_withdrawal( int account, long sdate, long edate )
     end = edate;
 
   for ( i=1; i <= numTrans; i++) {
+    long date = GetTransLDate (trans, i);
 
-    if ( GetTransLDate(trans, i) < start ) 
+    if (date < start) 
       continue;
-    if ( GetTransLDate(trans, i) > end ) 
+    if (date > end) 
       break;
 
+#if 0
+    if (GetTransType(trans, i) == T_SELL) {
+      /* - since T_SELL shares are negative. */
+      double cur_val = -GetTransShares(trans, i) * GetTransNav(trans, i);
+
+      /* If we've sold more than bought, increase withdraw */
+      if (cur_val > bought_val) {
+        withdraw += (cur_val - bought_val);
+	bought_val = 0.0;
+
+      } else 
+        bought_val -= cur_val;
+    }
+
+    else if ( GetTransType(trans, i) == T_BUY) 
+      bought_val += GetTransShares(trans, i) * GetTransNav(trans, i);
+
+#else
+    exchg = rate_exch (account, date);
+
     if ( GetTransType(trans, i) == T_SELL ) 
       /* - since T_SELL shares are negative. */
-      withdraw += (-GetTransShares(trans, i) * GetTransNav(trans, i));
+      withdraw += (-GetTransShares(trans, i) * GetTransNav(trans, i) * exchg);
+#endif
 
     /* divs only if reinvest off. */
     reinvest = GetTransFlag (trans, i, TRANS_REINVEST);
     if ( GetTransType(trans,i) == T_DIST && !reinvest )
-      withdraw += GetTransShares(trans, i) * GetTransNav(trans, i);
+      withdraw += (GetTransShares(trans, i) * GetTransNav(trans, i) * exchg);
   }
 
   /* withdraw is positive for any sales or div distributions */
   return ( withdraw );
 }
 
-
 /* How much gain came out of the account not including load which just
 ** evaporated. */
-double account_distrib( int account, NAV *nav )
-{
-  int i;
-  double withdraw = 0.0;
-  long maxday = 0;
-
-  int numTrans;
-  int reinvest;
-  void *trans;
-
-  getAccount( account, ACCOUNT_NUM_TRANS, &numTrans );
-  getAccount( account, ACCOUNT_TRANS, &trans );
-
-  if ( nav != NULL )
-    maxday = navToLDate( nav );
-  else
-    maxday = GetTransLDate( trans, numTrans );
-
-  for ( i=1; i <= numTrans; i++) {
-    if ( GetTransLDate(trans, i) > maxday ) 
-      /* user specified date less then some number of transactions */
-      break;
-
-    /* divs only if reinvest off. */
-    reinvest = GetTransFlag (trans, i, TRANS_REINVEST);
-    if ( GetTransType(trans,i) == T_DIST && !reinvest )
-      withdraw += GetTransShares(trans, i) * GetTransNav(trans, i);
-  }
-
-  /* withdraw is positive for any sales or div distributions */
-  return ( withdraw );
-}
-
 double rate_distrib( int account, long sdate, long edate )
 {
   int i;
@@ -826,23 +832,23 @@ double rate_distrib( int account, long sdate, long edate )
     end = edate;
 
   for ( i=1; i <= numTrans; i++) {
-
-    if ( GetTransLDate(trans, i) < start ) 
+    long date = GetTransLDate (trans, i);
+    if (date < start) 
       continue;
-    if ( GetTransLDate(trans, i) > end ) 
+    if (date > end) 
       break;
 
     /* divs only if reinvest off. */
     reinvest = GetTransFlag (trans, i, TRANS_REINVEST);
     if ( GetTransType(trans,i) == T_DIST && !reinvest )
-      withdraw += GetTransShares(trans, i) * GetTransNav(trans, i);
+      withdraw += (GetTransShares(trans, i) * GetTransNav(trans, i) *
+		   rate_exch (account, date));
   }
 
   /* withdraw is positive for any sales or div distributions */
   return ( withdraw );
 }
 
-
 /* 
 ** Calculate yield between start and end dates.  Return more info if 'result'
 ** non-NULL. 
@@ -857,6 +863,7 @@ double rate_yield( int account, long sdate, long edate, YIELD *result )
 
   double value = 0.0;
   double div = 0.0;
+  double exch = 1.0;
 
   int numTrans;
   void *trans;
@@ -877,10 +884,10 @@ double rate_yield( int account, long sdate, long edate, YIELD *result )
     end = edate;
 
   for ( i=1; i <= numTrans; i++) {
-
-    if ( GetTransLDate(trans, i) < start ) 
+    long date = GetTransLDate (trans, i);
+    if (date < start) 
       continue;
-    if ( GetTransLDate(trans, i) > end ) 
+    if (date > end) 
       break;
 
     /* Yield = dividend value/start shares/start price */
@@ -892,10 +899,11 @@ double rate_yield( int account, long sdate, long edate, YIELD *result )
       /* / start shares */
       shares = rate_shares (account, FIRST_DATE, GetTransLDate(trans, i-1));
       if (shares > 0.0) {
+	exch = rate_exch (account, date);
 
         /* Portfolio yield */
-        value += (shares * GetTransNav (trans, i));
-        div += (yield * GetTransNav (trans, i));
+        value += (shares * GetTransNav (trans, i) * exch);
+        div += (yield * GetTransNav (trans, i) * exch);
 
         /* Account yield */
         yield /= shares;
