@@ -1,6 +1,6 @@
 /*
-  Xinvest Copyright 1997 Mark Buser,
-  All Rights Reserved.
+  Xinvest Copyright (c)1997,2000 
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -20,11 +20,14 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 1.2 $ $Date: 1997/09/20 17:01:21 $
+  $Revision: 1.3 $ $Date: 2000/01/11 22:19:26 $
 */
 #ifndef report_h
 #define report_h
 
+/* Report initialization */
+void reportInit (Widget, char *);
+
 /* Report refresh */
 void displayReport (int);
 
