@@ -1,6 +1,6 @@
-"Xinvest.title: 				Xinvest 2.5.1",
+"Xinvest.title: 				Xinvest 2.6",
 "Xinvest.fontList: -*-helvetica-bold-r-*-*-*-100-*-*-*-*-*-*=small,\
--*-helvetica-bold-r-*-*-*-180-*-*-*-*-*-*=large",
+-*-helvetica-bold-r-*-*-*-140-*-*-*-*-*-*=large",
 "*Butform.fractionBase:			7",
 "*Quit.topPosition:			0",
 "*About.topPosition:			1",
@@ -25,14 +25,18 @@
 "*Acctform.button_1.labelString:		Open Accounts",
 "*Acctform.button_2.labelString:		Portfolio",
 "*Screenbut.labelString:			Next/Prev Screen",
-"*Timeform.button_0.labelString:		1 Day",
-"*Timeform.button_1.labelString:		7 Day",
-"*Timeform.button_2.labelString:		30 Day ",
-"*Timeform.button_3.labelString:		1 Quarter",
-"*Timeform.button_4.labelString:		Year to Date",
-"*Timeform.button_5.labelString:		1 Year",
-"*Timeform.button_6.labelString:		Since Inception",
-"*Timeform.button_7.labelString:		Custom",
+"*Timesform.button_0.labelString:	1 Day",
+"*Timesform.button_1.labelString:	7 Day",
+"*Timesform.button_2.labelString:	30 Day ",
+"*Timesform.button_3.labelString:	1 Quarter",
+"*Timesform.button_4.labelString:	Year to Date",
+"*Timesform.button_5.labelString:	1 Year",
+"*Timelform.button_0.labelString:	2 Years",
+"*Timelform.button_1.labelString:	3 Years",
+"*Timelform.button_2.labelString:	5 Years",
+"*Timelform.button_3.labelString:	10 Years",
+"*Timelform.button_4.labelString:	Since Inception",
+"*Timelform.button_5.labelString:	Custom",
 "*prevTrans.labelString:			Previous Transaction",
 "*nextTrans.labelString:			Next Transaction",
 "*firstTrans.labelString:		First Transaction",
@@ -79,8 +83,10 @@
 "*Filemenu.button_3.mnemonic:		S",
 "*Filemenu.button_4.labelString:		Save As...",
 "*Filemenu.button_4.mnemonic:		A",
-"*Filemenu.button_5.labelString:		Quit",
-"*Filemenu.button_5.mnemonic:		Q",
+"*Filemenu.button_5.labelString:		Save Session",
+"*Filemenu.button_5.mnemonic:		v",
+"*Filemenu.button_6.labelString:		Quit",
+"*Filemenu.button_6.mnemonic:		Q",
 "*Toolmenu.tearOffModel:			XmTEAR_OFF_ENABLED",
 "*Toolmenu*fontList:	-*-helvetica-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
 "*Toolmenu.button_0.labelString:		About",
@@ -108,6 +114,10 @@
 "*Editmenu.button_2.mnemonic:		P",
 "*Editmenu.button_2.accelerator:		Ctrl<Key>V",
 "*Editmenu.button_2.acceleratorText:	Ctrl+V",
+"*Editmenu.button_3.labelString:		Preferences...",
+"*Editmenu.button_3.mnemonic:		f",
+"*Editmenu.button_3.accelerator:		Ctrl<Key>f",
+"*Editmenu.button_3.acceleratorText:	Ctrl+f",
 "*Accountmenu*fontList:	-*-helvetica-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
 "*Accountmenu.button_0.labelString:	Previous",
 "*Accountmenu.button_0.mnemonic:		P",
@@ -193,22 +203,22 @@
 "*monthoptmenu.button_11.mnemonic:	D",
 "*Timeframe.shadowType:			SHADOW_ETCHED_IN",
 "*Timeframe*fontList:		-*-helvetica-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
-"*Timeframe.leftOffset:			0",
+"*Timeframe.leftOffset:			24",
 "*TimeLabel.labelString:			Report Period",
 "*TimeLabel.childVerticalAlignment:	ALIGNMENT_WIDGET_TOP",
-"*Timeform.fractionBase:			8",
-"*Timeform.*.shadowThickness:		1",
-"*Timeform.*.highlightThickness:		1",
-"*Timeform*indicatorOn:			False",
-"*Timeform*fillOnSelect:			True",
-"*Timeform.button_0.leftPosition:	0",
-"*Timeform.button_1.leftPosition:	1",
-"*Timeform.button_2.leftPosition:	2",
-"*Timeform.button_3.leftPosition:	3",
-"*Timeform.button_4.leftPosition:	4",
-"*Timeform.button_5.leftPosition:	5",
-"*Timeform.button_6.leftPosition:	6",
-"*Timeform.button_7.leftPosition:	7",
+"*Timerow.XmForm.fractionBase:		6",
+"*Timerow.XmForm.*.shadowThickness:	1",
+"*Timerow.XmForm.*.highlightThickness:	1",
+"*Timerow.XmForm*indicatorOn:		False",
+"*Timerow.XmForm*fillOnSelect:		True",
+"*Timerow.XmForm.button_0.leftPosition:	0",
+"*Timerow.XmForm.button_1.leftPosition:	1",
+"*Timerow.XmForm.button_2.leftPosition:	2",
+"*Timerow.XmForm.button_3.leftPosition:	3",
+"*Timerow.XmForm.button_4.leftPosition:	4",
+"*Timerow.XmForm.button_5.leftPosition:	5",
+"*Timerow.XmForm.button_6.leftPosition:	6",
+"*Timerow.XmForm.button_7.leftPosition:	7",
 "*Acctframe.shadowType:			SHADOW_ETCHED_IN",
 "*Acctframe*fontList:		-*-helvetica-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
 "*Acctframe.topOffset:			25",
@@ -234,7 +244,7 @@
 "*Valrow.orientation:			VERTICAL",
 "*Valrow.numColumns:			1",
 "*Valrow.button_0.labelString:		Details",
-"*Valrow.button_1.labelString:		Annualize",
+"*Valrow.button_1.labelString:		Return Details",
 "*Valrow.button_2.labelString:		Live Window",
 "*Screenbut.indicatorOn:			False",
 "*Screenbut.fillOnSelect:		True",
@@ -298,10 +308,10 @@
 "*Graphvrow*label_5.labelString:		IRR",
 "*Graphvrow*label_6.labelString:		TR",
 "*Graphvrow*label_7.labelString:		Constant",
-"*Graphvrow*label_8.labelString:		Shares (ACC)",
-"*Graphvrow*label_9.labelString:		Cost (ACC)",
-"*Graphvrow*label_10.labelString:	Value (ACC)",
-"*Graphvrow*label_11.labelString:	Distrib (ACC)",
+"*Graphvrow*label_8.labelString:		Shares (Sum)",
+"*Graphvrow*label_9.labelString:		Cost (Sum)",
+"*Graphvrow*label_10.labelString:	Value (Sum)",
+"*Graphvrow*label_11.labelString:	Distrib (Sum)",
 "*Graphvrow*label_12.labelString:	Price (MAVG)",
 "*Graphvrow*label_13.labelString:	Shares (MAVG)",
 "*Graphvrow*label_14.labelString:	Cost (MAVG)",
@@ -312,13 +322,13 @@
 "*Graphscale.orientation:		VERTICAL",
 "*Graphscale.maximum:			52",
 "*Graphscale.minimum:			1",
-"*Graphscale.value:			13",
+"*Graphscale.value:			10",
 "*Graphscale.editable:			True",
 "*Graphscale.showValue:			True",
 "*Graphscale.showArrows:			EACH_SIDE",
 "*Graphscale.slidingMode:		SLIDER",
 "*Graphscale.sliderMark:			THUMB_MARK",
-"*Graphslabel.labelString:		Trans",
+"*Graphslabel.labelString:		Weeks",
 "*Graphcform.topOffset:			10",
 "*Graphvlabel.labelString:		Constant",
 "*Graphvstart.columns:			7",
@@ -350,7 +360,7 @@
 "*Portbutform.Clear.rightPosition:	4",
 "*Portbutform*recomputeSize:		False",
 "*Portpercentlabel.alignment:		ALIGNMENT_CENTER",
-"*Portpercentlabel.labelString:		Category    Percent   Value",
+"*Portpercentlabel.labelString:		Category   Percent       Value",
 "*Portform*Portpercentlabel.fontList: -*-fixed-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
 "*Portform*XmList.fontList:  	-*-fixed-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
 "*Portpercentlist*visibleItemCount:	5",
@@ -376,6 +386,46 @@
 "*Butform.topOffset:			3",
 "*Butform.leftOffset:			3",
 "*Butform.rightOffset:			3",
+"*PrefPref.title:			Preferences",
+"*PrefPref*XmFrame.shadowType:		SHADOW_ETCHED_IN",
+"*PrefPref*fontList:		-*-helvetica-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
+"*PrefPref*indicatorSize:		15",
+"*PrefBack.labelString:			Auto Account Backup",
+"*PrefBack*XmForm.allowOverlap:		False",
+"*PrefBack.form_0.button_0.labelString:	Backup on Save",
+"*PrefBack.form_0.button_0.alignment:	ALIGNMENT_BEGINNING",
+"*PrefBack.form_0.button_0.set:		True",
+"*PrefBack.form_0.label_0.labelString:	File Extension:",
+"*PrefBack.form_0.label_0.leftOffset:	30",
+"*PrefBack.form_0.text_0.value:		bak",
+"*PrefBack.form_0.text_0.columns:	3",
+"*PrefDate.labelString:			Display Date Format",
+"*PrefDateOpt.labelString:		Date Format:",
+"*PrefDateOpt.button_0.labelString:	Localized",
+"*PrefDateOpt.button_1.labelString:	mm/dd/yyyy",
+"*PrefDateOpt.button_2.labelString:	dd/mm/yyyy",
+"*PrefCurr.labelString:			Display Monetary Format",
+"*PrefCurrOpt.labelString:		Numeric Format:",
+"*PrefCurrOpt.button_0.labelString:	Localized",
+"*PrefCurrOpt.button_1.labelString:	1,000.00",
+"*PrefCurrOpt.button_2.labelString:	1.000,00",
+"*PrefCurr*label_0.labelString:		Currency Symbol:",
+"*PrefCurr*label_0.leftOffset:		5",
+"*PrefCurr*text_0.value:			$",
+"*PrefCurr*text_0.columns:		4",
+"*PrefCurr.XmForm.button_0.labelString:	Use Currency Exchange Rates",
+"*PrefCurr.XmForm.button_0.set:		True",
+"*PrefPrec.labelString:		        Arithmetic Precision",
+"*PrefPrecOpt.labelString:		Digits:",
+"*PrefPrecOpt.button_0.labelString:	0",
+"*PrefPrecOpt.button_1.labelString:	1",
+"*PrefPrecOpt.button_2.labelString:	2",
+"*PrefPrecOpt.button_3.labelString:	3",
+"*PrefPrecOpt.button_4.labelString:	4",
+"*PrefPrecOpt.button_5.labelString:	5",
+"*PrefPrecOpt.button_6.labelString:	6",
+"*PrefPref*ButForm.button_0.labelString:	Ok",
+"*PrefPref*ButForm.button_1.labelString:	Cancel",
 "*Help*topicframe.shadowType:		SHADOW_ETCHED_IN",
 "*Help*topiclist.visibleItemCount:	15",
 "*Help*textframe.shadowType:		SHADOW_ETCHED_IN",
@@ -397,8 +447,28 @@
 "*Accountsel.okLabelString:              Select",
 "*Accountsel*fontList:	-*-helvetica-bold-r-*-*-*-120-*-*-*-*-iso8859-*",
 "*Report.dialogTitle:			Report",
-"*ReportScroll.width:			600",
-"*ReportScroll.height:			200",
+"*Report.allowShellResize:		True",
+"*ReportScroll.scrollBarDisplayPolicy:	static",
+"*ReportScroll.width:			670",
+"*ReportScroll.height:			240",
+"*ReportDrawing.width:			670",
+"*ReportDrawing.height:			240",
+"*Report.value.labelString:		Value",
+"*Report.price.labelString:		Price",
+"*Report.share.labelString:		Shares",
+"*Report.dValue.labelString:		Value Change",
+"*Report.dPrice.labelString:		Price Change",
+"*Report.dShare.labelString:		Share Change",
+"*Report.cost.labelString:		Additions",
+"*Report.debit.labelString:		Withdrawals",
+"*Report.fee.labelString:		Fees",
+"*Report.tr.labelString:			Total Return",
+"*Report.irr.labelString:		Internal Return (IRR)",
+"*Report.yield.labelString:		Yield",
+"*Report.gain.labelString:		Capital Gain",
+"*Report.dist.labelString:		Distribution Gain",
+"*Report.na.labelString:			N/A",
+"*Report.port.labelString:		Portfolio",
 "TipShell*foreground:			Black",
 "TipShell*background:			Yellow",
 "Xinvest.color0:				Red",
@@ -409,3 +479,8 @@
 "Xinvest.color5:				Brown",
 "Xinvest.color6:				Orange",
 "Xinvest.color7:				Grey100",
+"Xinvest.colorRed:			Red",
+"Xinvest.colorGreen:			Green3",
+"Xinvest.colorGrey:			Grey60",
+"Xinvest.colorWhite:			White",
+"Xinvest.colorBlack:			Black",
