@@ -19,10 +19,13 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.0 $ $Date: 1996/11/21 01:31:56 $
+  $Revision: 2.1 $ $Date: 1998/04/26 18:58:41 $
 */
 
-void sessDie ( Widget, XtPointer, XtPointer call_data);
-void sessSave ( Widget, XtPointer, XtPointer call_data);
-void sessResume ( Widget, XtPointer, XtPointer call_data);
-int restoreState ( char *);
+void sessDie (Widget, XtPointer, XtPointer);
+void sessSave (Widget, XtPointer, XtPointer);
+void sessResume (Widget, XtPointer, XtPointer);
+
+int restoreState (char *);
+int saveState (char *);
+char *sessSaveFile (Boolean);
