@@ -1,5 +1,6 @@
 /*
-  Xinvest is copyright 1995, 1996 by Mark Buser.
+  Xinvest/Xquote Copyright 1995-97 Mark Buser,
+  All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -9,7 +10,7 @@
   
   All redistributions must be in their
   entirety as originally distributed.
-  Feel free to modify Xinvest, but
+  Feel free to modify Xinvest/Xquote, but
   modified versions may not be distributed
   without prior consent of the author.
   
@@ -19,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.1 $ $Date: 1996/12/22 19:18:05 $
+  $Revision: 2.2 $ $Date: 1997/12/07 22:17:04 $
 */
 
 #ifndef status_h
@@ -33,7 +34,11 @@
 #define INFO XmDIALOG_INFORMATION
 #define LOG  XmDIALOG_MESSAGE
 
+extern char errmsg[256];
 void write_status (char *info, int level);
+#ifdef XQUOTE
+void write_status_line (char *);
+#endif
 
 int bound_ok ( int, int, int *, int );
 int suppressed ();
