@@ -1,5 +1,6 @@
 /*
-  Xinvest is copyright 1995,1996 by Mark Buser.
+  Xinvest Copyright (c)1995-98 Mark Buser,
+  All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -19,7 +20,7 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.2 $ $Date: 1997/02/11 01:19:41 $
+  $Revision: 2.6 $ $Date: 1998/04/30 01:11:10 $
 */
 #ifndef util_h
 #define util_h
@@ -30,6 +31,12 @@ int path_length();
 void removeFileOption ( int *, char **);  /* Remove -f from passed argc/argv */
 void processFileOption ( int, char **);   /* Load -f files from argc/argv */
 
+#define UTILCURR 1			  /* Print as currency */
+#define UTILNUM  0                        /* Print as non-currency */
+char *utilCurrOut (double, int);          /* Change double to string, int is
+                                             currency flag. */
+char *utilDateOut (long);                 /* Change long to string */
+
 #ifdef NeXT
 #include <stdlib.h>
 #include <dirent.h>
@@ -47,12 +54,12 @@ char *getcwd (char *, size_t);
 char *strdup( const char *);
 #endif
 
-#ifdef NEED_STRCASECMP
+#if defined (NEED_STRCASECMP)
 int strcasecmp (char *, char *);
 int strncasecmp (char *, char *, int);
 #endif 
 
-#if defined(__FreeBSD__) || defined (__sgi)
+#if defined (NEED_STRPTIME)
 char *strptime ( char *, char *, struct tm *);
 #endif
 
