@@ -1,6 +1,6 @@
 /*
-  Xinvest Copyright 1995-97 Mark Buser,
-  All Rights Reserved.
+  Xinvest Copyright 1995-97, 2000 
+  Mark Buser, All Rights Reserved.
 
   Permission is hereby granted to copy
   and freely distribute copies of this
@@ -20,11 +20,10 @@
   liable for any damages resulting from
   the use of this software.
 
-  $Revision: 2.29 $ $Date: 1997/09/20 17:04:03 $
+  $Revision: 2.41 $ $Date: 2000/01/20 23:34:33 $
 */
 
 #include <stdio.h>
-#include <time.h>
 #include <unistd.h>
 
 #include <X11/Xlib.h>
@@ -43,9 +42,11 @@
 #include "graph.h"
 #include "nav.h"
 #include "pixmap.h"
+#include "pref.h"
 #include "rate.h"
 #include "remote.h"
 #include "report.h"
+#include "resource.h"
 #include "session.h"
 #include "status.h"
 #include "tooltips.h"
@@ -61,7 +62,9 @@ extern void helpCB();
 
 
 /* Globals */
-static char version[] = "Xinvest 2.4";
+Widget Toplevel;
+
+char version[] = "Xinvest 2.6";
 
 static char *portoptmenu[] = { "Display", "Root", "Accounts", "Flatten" };
 
@@ -81,13 +84,17 @@ static MENUITEMS file[] = {
  { "button_3",    XmVaPUSHBUTTON, fileCB },
  { "button_4",    XmVaPUSHBUTTON, fileCB },
  { "separator_0", XmVaSEPARATOR,  NULL },
- { "button_5",    XmVaPUSHBUTTON, fileCB }
+ { "button_5",    XmVaPUSHBUTTON, fileCB },
+ { "separator_1", XmVaSEPARATOR,  NULL },
+ { "button_6",    XmVaPUSHBUTTON, fileCB }
 };
 
 static MENUITEMS edit[] = {
  { "button_0",    XmVaPUSHBUTTON, editCB },
  { "button_1",    XmVaPUSHBUTTON, editCB },
- { "button_2",    XmVaPUSHBUTTON, editCB }
+ { "button_2",    XmVaPUSHBUTTON, editCB },
+ { "separator_0", XmVaSEPARATOR,  NULL },
+ { "button_3",    XmVaPUSHBUTTON, editCB },
 };
 
 static MENUITEMS tool[] = {
@@ -156,7 +163,7 @@ static BUTTONITEMS acctbar[] = {
   }
 };
 
-static BUTTONITEMS timebar[] = {
+static BUTTONITEMS timesbar[] = {
   { "button_0", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
     (XtPointer)NULL, NULL, reportSetTime, NULL 
   },
@@ -174,11 +181,25 @@ static BUTTONITEMS timebar[] = {
   },
   { "button_5", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
     (XtPointer)NULL, NULL, reportSetTime, NULL 
-  },
-  { "button_6", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
+  }
+};
+static BUTTONITEMS timelbar[] = {
+  { "button_0", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
     (XtPointer)NULL, NULL, reportSetTime, NULL 
   },
-  { "button_7", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
+  { "button_1", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
+    (XtPointer)NULL, NULL, reportSetTime, NULL 
+  },
+  { "button_2", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
+    (XtPointer)NULL, NULL, reportSetTime, NULL 
+  },
+  { "button_3", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
+    (XtPointer)NULL, NULL, reportSetTime, NULL 
+  },
+  { "button_4", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
+    (XtPointer)NULL, NULL, reportSetTime, NULL 
+  },
+  { "button_5", XmVaTOGGLEBUTTON, (Pixmap)NULL, (Pixmap)NULL, (Pixmap)NULL,
     (XtPointer)NULL, NULL, reportSetTime, NULL 
   }
 };
@@ -197,7 +218,8 @@ Widget Filecwdlabel;
 Widget Listfile;
 static Widget Infoframe;
 static Widget Reportform; 
-Widget Timeform;
+Widget Timesform;
+Widget Timelform;
 Widget Valrow;
 static Widget Graphform; 
 Widget Graphhbar; 
@@ -238,7 +260,7 @@ extern void  calcFuncSel();
 extern void  calcTextSel();
 extern void  calcCompSel();
 
-void main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 
   XtAppContext app;
@@ -249,7 +271,7 @@ void main (int argc, char **argv)
   XmFontContext   fontContext;
 
   /* Main Window Widgets */
-  Widget Toplevel;
+/*Widget Toplevel; */
   Widget Mainform;
    Widget Menubar;
 /*   Widget Filemenu; */
@@ -281,7 +303,9 @@ void main (int argc, char **argv)
           Widget ReportInnerform;
            Widget Screenbut;
            Widget Timeframe;
-/*          Widget Timeform; */
+            Widget Timerow;
+/*           Widget Timesform; */
+/*           Widget Timelform; */
            Widget Valframe;
 /*          Widget Valrow; */
            Widget Acctframe;
@@ -404,16 +428,21 @@ void main (int argc, char **argv)
     cmap = NewColormap (dpy, cmap );
 
   { /* Application resource colors get added to color list. */
-    Pixel appcolors[8];
+    Pixel appcolors[COLOR_DEF];
 
-    appcolors[0] = appdata.color0; 
-    appcolors[1] = appdata.color1; 
-    appcolors[2] = appdata.color2; 
-    appcolors[3] = appdata.color3; 
-    appcolors[4] = appdata.color4; 
-    appcolors[5] = appdata.color5; 
-    appcolors[6] = appdata.color6; 
-    appcolors[7] = appdata.color7; 
+    appcolors[0] = appdata.color0;
+    appcolors[1] = appdata.color1;
+    appcolors[2] = appdata.color2;
+    appcolors[3] = appdata.color3;
+    appcolors[4] = appdata.color4;
+    appcolors[5] = appdata.color5;
+    appcolors[6] = appdata.color6;
+    appcolors[7] = appdata.color7;
+    appcolors[8] = appdata.colorRed;
+    appcolors[9] = appdata.colorGreen;
+    appcolors[10] = appdata.colorGrey;
+    appcolors[11] = appdata.colorWhite;
+    appcolors[12] = appdata.colorBlack;
 
     cmap = InitColor ( Toplevel, cmap, appcolors );
     if ( cmap == (Colormap)NULL) {
@@ -1107,14 +1136,18 @@ void main (int argc, char **argv)
 	      NULL );
   XtVaCreateManagedWidget("TimeLabel", xmLabelGadgetClass, Timeframe,
                           XmNchildType, XmFRAME_TITLE_CHILD, NULL);
-  timebar[0].sens = GetPixmap (PDAY, NORMAL);
-  timebar[1].sens = GetPixmap (PWEEK, NORMAL);
-  timebar[2].sens = GetPixmap (PMONTH, NORMAL);
-  timebar[3].sens = GetPixmap (PQTR, NORMAL);
-  timebar[4].sens = GetPixmap (PYTD, NORMAL);
-  timebar[5].sens = GetPixmap (PYEAR, NORMAL);
-  timebar[6].sens = GetPixmap (PFIRST, NORMAL);
-  timebar[7].sens = GetPixmap (PPICK, NORMAL);
+  timesbar[0].sens = GetPixmap (PDAY, NORMAL);
+  timesbar[1].sens = GetPixmap (PWEEK, NORMAL);
+  timesbar[2].sens = GetPixmap (PMONTH, NORMAL);
+  timesbar[3].sens = GetPixmap (PQTR, NORMAL);
+  timesbar[4].sens = GetPixmap (PYTD, NORMAL);
+  timesbar[5].sens = GetPixmap (PYEAR, NORMAL);
+  timelbar[0].sens = GetPixmap (P2YEAR, NORMAL);
+  timelbar[1].sens = GetPixmap (P3YEAR, NORMAL);
+  timelbar[2].sens = GetPixmap (P5YEAR, NORMAL);
+  timelbar[3].sens = GetPixmap (P10YEAR, NORMAL);
+  timelbar[4].sens = GetPixmap (PFIRST, NORMAL);
+  timelbar[5].sens = GetPixmap (PPICK, NORMAL);
   /* Button bar made below */
 
 
@@ -1167,34 +1200,45 @@ void main (int argc, char **argv)
                           NULL);
   XtAddCallback (Reportbut, XmNactivateCallback, 
                  (XtCallbackProc) reportGenerate, (XtPointer) NULL);  
+  /* One of the params to whether Reportbut is sensitive */
+  XtVaSetValues (Acctform, XmNuserData, Reportbut, NULL);
 
   /* next/previous screen */
   Screenbut = XtVaCreateManagedWidget (
-                "Screenbut", xmPushButtonWidgetClass, Reportform,
+                "Screenbut", xmPushButtonWidgetClass, ReportInnerform,
                 XmNlabelType,    XmPIXMAP,
                 XmNlabelPixmap,  GetPixmap(PNEXT,NORMAL),
                 XmNlabelInsensitivePixmap, GetPixmap(PNEXT,INSENS),
                 XmNsensitive,    False,
-                XmNtopAttachment, XmATTACH_WIDGET,
-                XmNtopWidget,     ReportInnerform,
+                XmNbottomAttachment, XmATTACH_FORM,
                 XmNrightAttachment, XmATTACH_FORM,
                 NULL);
   installToolTips (Screenbut);
   XtAddCallback (Screenbut, XmNactivateCallback, 
                  (XtCallbackProc)reportCustomTime, (XtPointer)ReportInnerform);  
-
   /* Moved from above so we can pass button widget */
-  timebar[7].userdata = (XtPointer) Screenbut;
+  timelbar[5].userdata = (XtPointer) Screenbut;
 
-  Timeform = makeButtonbar (Timeframe, "Timeform", XmHORIZONTAL, 
-                            timebar, XtNumber(timebar));
-  XtManageChild (Timeform);
+  /* One of the params to whether Reportbut is sensitive */
+  Timerow = XtVaCreateManagedWidget ("Timerow", xmRowColumnWidgetClass, 
+                                     Timeframe, XmNuserData, Reportbut, NULL);
+  Timesform = makeButtonbar (Timerow, "Timesform", XmHORIZONTAL, 
+                             timesbar, XtNumber(timesbar));
+  /* Row 0 of time frames */
+  XtVaSetValues (Timesform, XmNuserData, 0, NULL);
+  XtManageChild (Timesform);
+
+  Timelform = makeButtonbar (Timerow, "Timelform", XmHORIZONTAL, 
+                            timelbar, XtNumber(timelbar));
+  /* Row 1 of time frames */
+  XtVaSetValues (Timelform, XmNuserData, 1, NULL);
+  XtManageChild (Timelform);
 
-  XtVaSetValues (Acctform, XmNuserData, Reportbut, NULL);
-  XtVaSetValues (Timeform, XmNuserData, Reportbut, NULL);
   
   XtManageChild (ReportInnerform);
 
+  /* Any report specific initialization */
+  reportInit (Toplevel, argv[0]);
   /********************/
     
 
@@ -1350,7 +1394,7 @@ void main (int argc, char **argv)
 
     if (font)
       XtVaSetValues ( Portpercentlist,
-                      XmNwidth, 35*font->max_bounds.width,
+                      XmNwidth, 36*font->max_bounds.width,
                       NULL);
   }
 
@@ -1574,6 +1618,9 @@ void main (int argc, char **argv)
   CenterWidget (Actform, Portform);
   CenterWidget (Actform, Calcform);
 
+  /* Initialize preferences from resources before any -restore */
+  prefInitState (argv[0]);
+
   if (appdata.restore)
     restoreState (appdata.restore);
 
@@ -1589,6 +1636,8 @@ void main (int argc, char **argv)
     processFileOption ( argc, argv );
 
   XtAppMainLoop ( app );
+
+  return (0);
 }
 
 
@@ -1629,7 +1678,7 @@ void toolCB ( Widget w, XtPointer client_data, XtPointer call_data)
             XtSetMappedWhenManaged ( Calcform, True );
             break;
   case 6:   /* Quit */
-            fileCB (w, (XtPointer)5, (XtPointer)NULL);
+            fileCB (w, (XtPointer)6, (XtPointer)NULL);
             break;
 
   case 0:   /* About */
